@@ -49,6 +49,10 @@
 #include "sbml/SBMLTypes.h"
 #include "sbml/packages/layout/common/LayoutExtensionTypes.h"
 
+#if (!defined LIBSBML_HAS_PACKAGE_LAYOUT)
+#error "This example requires libSBML to be built with the layout extension."
+#endif
+
 LIBSBML_CPP_NAMESPACE_USE
 
 int main(int argc,char** argv){
