@@ -8,17 +8,17 @@
 # This file is part of libSBML.  Please visit http://sbml.org for more
 # information about SBML, and the latest version of libSBML.
 #
-# Copyright (C) 2009-2012 jointly by the following organizations: 
+# Copyright (C) 2009-2012 jointly by the following organizations:
 #     1. California Institute of Technology, Pasadena, CA, USA
 #     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
-#  
+#
 # Copyright (C) 2006-2008 by the California Institute of Technology,
-#     Pasadena, CA, USA 
-#  
-# Copyright (C) 2002-2005 jointly by the following organizations: 
+#     Pasadena, CA, USA
+#
+# Copyright (C) 2002-2005 jointly by the following organizations:
 #     1. California Institute of Technology, Pasadena, CA, USA
 #     2. Japan Science and Technology Agency, Japan
-# 
+#
 # This library is free software; you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation.  A copy of the license agreement is provided
@@ -37,19 +37,19 @@ function delete_file_or_dir {
 FILE=$1
 
 if [ -d "$FILE" ]; then
-	rm -rf "$FILE"
+rm -rf "$FILE"
 fi
 
 if [ -e "$FILE" ]; then
-	rm -f "$FILE"
+rm -f "$FILE"
 fi
 
 }
 
 if [ ${EUID} != 0 ] ; then
-  echo "Please run this shell script as the user 'root'."
-  exit 1
-fi	
+echo "Please run this shell script as the user 'root'."
+exit 1
+fi
 
 cd "$INSTALL_DIR"
 
@@ -235,6 +235,8 @@ delete_file_or_dir lib/libsbml.5.dylib
 delete_file_or_dir lib/libsbml.5.3.0.dylib
 delete_file_or_dir lib/libsbml.5.4.0.dylib
 delete_file_or_dir lib/libsbml.5.4.1.dylib
+delete_file_or_dir lib/libsbml.5.5.0.dylib
+delete_file_or_dir lib/libsbml.5.6.0.dylib
 delete_file_or_dir lib/libsbml.a
 delete_file_or_dir lib/libsbml.la
 delete_file_or_dir lib/libsbmlj.jnilib
@@ -289,6 +291,8 @@ delete_file_or_dir lib/python2.7/site-packages/libsbml/_libsbml.so
 delete_file_or_dir lib/python2.7/site-packages/libsbml-5.3.0-py2.7.egg-info
 delete_file_or_dir lib/python2.7/site-packages/libsbml-5.4.0-py2.7.egg-info
 delete_file_or_dir lib/python2.7/site-packages/libsbml-5.4.1-py2.7.egg-info
+delete_file_or_dir lib/python2.7/site-packages/libsbml-5.5.0-py2.7.egg-info
+delete_file_or_dir lib/python2.7/site-packages/libsbml-5.6.0-py2.7.egg-info
 delete_file_or_dir lib/python2.7/site-packages/libsbml.pth
 delete_file_or_dir lib/python2.7/site-packages/libsbml
 
@@ -298,6 +302,8 @@ delete_file_or_dir lib/python2.6/site-packages/libsbml/_libsbml.so
 delete_file_or_dir lib/python2.6/site-packages/libsbml-5.3.0-py2.6.egg-info
 delete_file_or_dir lib/python2.6/site-packages/libsbml-5.4.0-py2.6.egg-info
 delete_file_or_dir lib/python2.6/site-packages/libsbml-5.4.1-py2.6.egg-info
+delete_file_or_dir lib/python2.6/site-packages/libsbml-5.5.0-py2.6.egg-info
+delete_file_or_dir lib/python2.6/site-packages/libsbml-5.6.0-py2.6.egg-info
 delete_file_or_dir lib/python2.6/site-packages/libsbml.pth
 delete_file_or_dir lib/python2.6/site-packages/libsbml
 
@@ -332,9 +338,9 @@ delete_file_or_dir bin/uninstall-libsbml-pkg.sh
 LIBSBML_PKGID=`${PKGUTIL} --pkgs | grep libsbml`
 
 if (echo "${LIBSBML_PKGID}" | grep -q -i libsbml); then
-  ${PKGUTIL} --forget ${LIBSBML_PKGID}
+${PKGUTIL} --forget ${LIBSBML_PKGID}
 fi
 
-echo 
+echo
 echo Uninstall finished successfully.
 
