@@ -92,6 +92,8 @@
 #include <sbml/math/MathML.h>
 #include <sbml/math/FormulaFormatter.h>
 #include <sbml/math/FormulaParser.h>
+#include <sbml/math/L3Parser.h>
+#include <sbml/math/L3ParserSettings.h>
 
 #include <sbml/xml/XMLAttributes.h>
 #include <sbml/xml/XMLNamespaces.h>
@@ -111,7 +113,7 @@
 #include <sbml/annotation/Date.h>
 #include <sbml/annotation/ModelCreator.h>
 #include <sbml/annotation/ModelHistory.h>
-#include <sbml/annotation/RDFAnnotation.h>
+#include <sbml/annotation/RDFAnnotationParser.h>
 
 #include <sbml/extension/ISBMLExtensionNamespaces.h>
 #include <sbml/extension/SBaseExtensionPoint.h>
