@@ -59,6 +59,7 @@ libsbmlclasses = ["AlgebraicRule",
                   "InitialAssignment",
                   "KineticLaw",
                   "libsbml",
+                  "L3ParserSettings",
                   "List",
                   "ListOf",
                   "ListOfCompartmentTypes",
@@ -549,6 +550,7 @@ def rewriteCommonReferences (docstring):
     docstring = re.sub(r'XMLErrorCode_t#',          target, docstring)
     docstring = re.sub(r'XMLErrorCategory_t#',      target, docstring)
     docstring = re.sub(r'XMLErrorSeverity_t#',      target, docstring)
+    docstring = re.sub(r'ParseLogType_t#',          target, docstring)
 
   return docstring
 
@@ -695,6 +697,10 @@ def sanitizeForHTML (docstring):
   Performs HTML transformations on the C++/Doxygen docstring.
   """
 
+  # Remove @~, which we use as a hack in Doxygen 1.7-1.8
+
+  docstring = docstring.replace(r'@~', '')
+
   # First do conditional section inclusion based on the current language.
   # Our possible conditional elements and their meanings are:
   #
@@ -800,7 +806,7 @@ def sanitizeForHTML (docstring):
   # cross-links just for the Java case, let's automate.  This needs to be
   # done better (e.g., by not hard-wiring the class names).
 
-  p = re.compile(r'(\W)(' + '|'.join(libsbmlclasses) + r')\b([^:])', re.DOTALL)
+  p = re.compile(r'([^a-zA-Z0-9_.">])(' + '|'.join(libsbmlclasses) + r')\b([^:])', re.DOTALL)
   if language == 'csharp':
     docstring = p.sub(translateClassRefCSharp, docstring)
   elif language == 'java':
@@ -870,11 +876,14 @@ def rewriteDocstringForJava (docstring):
 
   docstring = sanitizeForHTML(docstring)
 
-  # Fix up for a problem introduced by sanitizeForHTML -- should fix
-  # properly some day.
+  # Fix up for a problem introduced by sanitizeForHTML: it puts {@link ...}
+  # into the arguments of functions mentioned in @see's, if the function
+  # has more than one argument.  This gets rid of the @link's.  This should
+  # be fixed properly some day.
 
-  p = re.compile('((@see|@throws)\s+[\w ,(]*){@link\s+([^}]+?)}')
-  docstring = p.sub(r'\1\3', docstring)
+  p = re.compile(r'((@see|@throws)\s+[\w\\ ,.\'"=<>()#]*?){@link\s+([^}]+?)}')
+  while re.search(p, docstring) != None:
+    docstring = p.sub(r'\1\3', docstring)
 
   # Inside of @see, change double colons to pound signs.
 
@@ -896,7 +905,7 @@ def rewriteDocstringForJava (docstring):
 
   # The syntax for @link is vastly different.
   
-  p = re.compile('@link([\s/*]+[\w\s,.:#()*]+[\s/*]+[\w():#]+[\s/*]*)@endlink', re.DOTALL)
+  p = re.compile('@link([\s/*]+[\w\s,.:#()*]+[\s/*]*[\w():#]+[\s/*]*)@endlink', re.DOTALL)
   docstring = p.sub(r'{@link \1}', docstring)
 
   # Outside of @see and other constructs, dot is used to reference members
@@ -959,7 +968,13 @@ def rewriteDocstringForCSharp (docstring):
 
   # Do replacements on some documentation text we sometimes use.
 
-  docstring = docstring.replace(r'libsbmlConstants', 'libsbmlcs.libsbml')
+  p = re.compile(r'libsbmlConstants([@.])')
+  docstring = p.sub(r'libsbmlcs.libsbml\1', docstring)
+
+  # Fix @link for constants that we forgot conditionalize in the source.
+
+  p = re.compile(r'@link +([A-Z_0-9]+?)@endlink', re.DOTALL)
+  docstring = p.sub(r'@link libsbml.\1@endlink', docstring)
 
   # Can't use math symbols.  Kluge around it.
 
@@ -1004,6 +1019,8 @@ def rewriteDocstringForPython (docstring):
 
   docstring = rewriteCommonReferences(docstring)  
 
+  # Take out the C++ comment start and end.
+
   docstring = docstring.replace('/**', '').replace('*/', '')
   p = re.compile('^(\s*)\*([ \t]*)', re.MULTILINE)
   docstring = p.sub(r'\2', docstring)
@@ -1122,7 +1139,7 @@ def processClassMethods(ostream, cclass):
   if language == 'python':
     written = {}
     for m in cclass.methods:
-      if written.has_key(m.name + m.args):
+      if m.name + m.args in written:
         continue
       if m.name.startswith('~'):
         continue
@@ -1134,7 +1151,7 @@ def processClassMethods(ostream, cclass):
         # a statement that there are multiple variants, we must check that
         # we're left with more than one non-internal method to document.
         count = 0
-        for argVariant in cclass.methodVariants[m.name].values():
+        for argVariant in list(cclass.methodVariants[m.name].values()):
           if re.search('@internal', argVariant.docstring) == None:
             count += 1
         if count <= 1:
@@ -1144,7 +1161,7 @@ def processClassMethods(ostream, cclass):
                  ' arguments\n they accept.  Each is described separately' + \
                  ' below.\n'
 
-        for argVariant in cclass.methodVariants[m.name].values():
+        for argVariant in list(cclass.methodVariants[m.name].values()):
           # Each entry in the methodVariants dictionary is itself a dictionary.
           # The dictionary entries are keyed by method arguments (as strings).
           # The dictionary values are the 'func' objects we use.
@@ -1183,7 +1200,7 @@ def formatMethodDocString (methodname, classname, docstring, isInternal, args=No
   elif language == 'csharp':
     pre  = '%csmethodmodifiers'
     # See the comment for the definition of 'overriders' for more info.
-    if overriders.has_key(classname) and methodname in overriders[classname]:
+    if classname in overriders and methodname in overriders[classname]:
       post = ' public new'
     else:
       post = ' public'
@@ -1298,7 +1315,7 @@ def main (args):
   """
 
   if len(args) != 6:
-    print(main.__doc__)
+    print((main.__doc__))
     sys.exit(1)
 
   global docincpath
