@@ -469,6 +469,19 @@ EventAssignment::divideAssignmentsToSIdByFunction(const std::string& id, const A
 }
 /** @endcond */
 
+/** @cond doxygen-libsbml-internal */
+void 
+EventAssignment::multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function)
+{
+  if (mVariable == id && isSetMath()) {
+    ASTNode* temp = mMath;
+    mMath = new ASTNode(AST_TIMES);
+    mMath->addChild(temp);
+    mMath->addChild(function->deepCopy());
+  }
+}
+/** @endcond */
+
 /** @cond doxygen-libsbml-internal */
 /*
  * Subclasses should override this method to write out their contained
@@ -1111,7 +1124,7 @@ EventAssignment_isSetMath (const EventAssignment_t *ea)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1141,7 +1154,7 @@ EventAssignment_setVariable (EventAssignment_t *ea, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
