@@ -464,6 +464,19 @@ InitialAssignment::divideAssignmentsToSIdByFunction(const std::string& id, const
 }
 /** @endcond */
 
+/** @cond doxygen-libsbml-internal */
+void 
+InitialAssignment::multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function)
+{
+  if (mSymbol == id && isSetMath()) {
+    ASTNode* temp = mMath;
+    mMath = new ASTNode(AST_TIMES);
+    mMath->addChild(temp);
+    mMath->addChild(function->deepCopy());
+  }
+}
+/** @endcond */
+
 /** @cond doxygen-libsbml-internal */
 /*
  * Subclasses should override this method to write out their contained
@@ -1105,7 +1118,7 @@ InitialAssignment_isSetMath (const InitialAssignment_t *ia)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1136,7 +1149,7 @@ InitialAssignment_setSymbol (InitialAssignment_t *ia, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
