@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2009-2011 jointly by the following organizations: 
+ * Copyright (C) 2009-2012 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
  *  
@@ -238,6 +238,11 @@ public:
    *
    * @param version an unsigned int, the SBML Version to assign to this
    * InitialAssignment
+   *
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the given @p level and @p version combination, or this kind
+   * of SBML object, are either invalid or mismatched with respect to the
+   * parent SBMLDocument object.
    * 
    * @note Upon the addition of a InitialAssignment object to an
    * SBMLDocument (e.g., using Model::addInitialAssignment(@if java InitialAssignment ia@endif)), the SBML
@@ -267,6 +272,11 @@ public:
    *
    * @param sbmlns an SBMLNamespaces object.
    *
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the given @p level and @p version combination, or this kind
+   * of SBML object, are either invalid or mismatched with respect to the
+   * parent SBMLDocument object.
+   *
    * @note Upon the addition of a InitialAssignment object to an
    * SBMLDocument (e.g., using Model::addInitialAssignment(@if java InitialAssignment ia@endif)), the SBML XML
    * namespace of the document @em overrides the value used when creating
@@ -289,12 +299,23 @@ public:
 
   /**
    * Copy constructor; creates a copy of this InitialAssignment.
+   *
+   * @param orig the object to copy.
+   * 
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the argument @p orig is @c NULL.
    */
   InitialAssignment (const InitialAssignment& orig);
 
 
   /**
    * Assignment operator for InitialAssignment.
+   *
+   * @param rhs The object whose values are used as the basis of the
+   * assignment.
+   *
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the argument @p rhs is @c NULL.
    */
   InitialAssignment& operator=(const InitialAssignment& rhs);
 
@@ -397,7 +418,7 @@ public:
    * The units are calculated based on the mathematical expression in the
    * InitialAssignment and the model quantities referenced by
    * <code>&lt;ci&gt;</code> elements used within that expression.  The
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * method returns the calculated units.
    *
    * Note that the functionality that facilitates unit analysis depends 
@@ -410,13 +431,13 @@ public:
    * units.  In those cases, it is not possible to calculate the units of
    * the overall expression without making assumptions.  LibSBML does not
    * make assumptions about the units, and
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * only returns the units as far as it is able to determine them.  For
    * example, in an expression <em>X + Y</em>, if <em>X</em> has
    * unambiguously-defined units and <em>Y</em> does not, it will return
    * the units of <em>X</em>.  <strong>It is important that callers also
    * invoke the method</strong>
-   * @if java InitialAssignment::containsUndeclaredUnits()@else containsUndeclaredUnits()@endif
+   * @if java InitialAssignment::containsUndeclaredUnits()@else containsUndeclaredUnits()@endif@~
    * <strong>to determine whether this situation holds</strong>.  Callers
    * may wish to take suitable actions in those scenarios.
    * 
@@ -436,7 +457,7 @@ public:
    * The units are calculated based on the mathematical expression in the
    * InitialAssignment and the model quantities referenced by
    * <code>&lt;ci&gt;</code> elements used within that expression.  The
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * method returns the calculated units.
    *
    * Note that the functionality that facilitates unit analysis depends 
@@ -449,13 +470,13 @@ public:
    * units.  In those cases, it is not possible to calculate the units of
    * the overall expression without making assumptions.  LibSBML does not
    * make assumptions about the units, and
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * only returns the units as far as it is able to determine them.  For
    * example, in an expression <em>X + Y</em>, if <em>X</em> has
    * unambiguously-defined units and <em>Y</em> does not, it will return
    * the units of <em>X</em>.  <strong>It is important that callers also
    * invoke the method</strong>
-   * @if java InitialAssignment::containsUndeclaredUnits()@else containsUndeclaredUnits()@endif
+   * @if java InitialAssignment::containsUndeclaredUnits()@else containsUndeclaredUnits()@endif@~
    * <strong>to determine whether this situation holds</strong>.  Callers
    * may wish to take suitable actions in those scenarios.
    * 
@@ -478,7 +499,7 @@ public:
    *
    * @note A return value of @c true indicates that the UnitDefinition
    * returned by
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * may not accurately represent the units of the expression.
    *
    * @see getDerivedUnitDefinition()
@@ -497,7 +518,7 @@ public:
    *
    * @note A return value of @c true indicates that the UnitDefinition
    * returned by
-   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif
+   * @if java InitialAssignment::getDerivedUnitDefinition()@else getDerivedUnitDefinition()@endif@~
    * may not accurately represent the units of the expression.
    *
    * @see getDerivedUnitDefinition()
@@ -528,7 +549,7 @@ public:
    * codes</em>.  In the C# language interface for libSBML, the type codes
    * are defined as static integer constants in the interface class @link
    * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
+   * the characters @c SBML_. @endif@~
    *
    * @return the SBML type code for this object, or @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
    *
@@ -624,6 +645,13 @@ public:
   virtual void divideAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function);
   /** @endcond */
 
+  /** @cond doxygen-libsbml-internal */
+  /**
+   * If this assignment assigns a value to the 'id' element, replace the 'math' object with the function (existing*function). 
+   */
+  virtual void multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function);
+  /** @endcond */
+
 protected:
   /** @cond doxygen-libsbml-internal */
 
@@ -753,7 +781,7 @@ public:
    * codes</em>.  In the C# language interface for libSBML, the type codes
    * are defined as static integer constants in the interface class @link
    * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
+   * the characters @c SBML_. @endif@~
    *
    * @return the SBML type code for this object, or @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
    *
@@ -786,7 +814,7 @@ public:
    * codes</em>.  In the C# language interface for libSBML, the type codes
    * are defined as static integer constants in the interface class @link
    * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
+   * the characters @c SBML_. @endif@~
    * 
    * @return the SBML type code for the objects contained in this ListOf
    * instance, or @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
@@ -893,6 +921,16 @@ public:
   virtual InitialAssignment* remove (const std::string& sid);
 
 
+  /**
+   * Returns the first child element found that has the given id in the model-wide SId namespace, or NULL if no such object is found.  Note that InitialAssignments do not actually have IDs, though the libsbml interface pretends that they do:  no initial assignment is returned by this function.
+   *
+   * @param id string representing the id of objects to find
+   *
+   * @return pointer to the first element found with the given id.
+   */
+  virtual SBase* getElementBySId(std::string id);
+  
+  
   /** @cond doxygen-libsbml-internal */
 
   /**
