@@ -588,7 +588,7 @@ KineticLaw::addParameter (const Parameter* p)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
-  else if (matchesSBMLNamespaces(static_cast<const SBase *>(p)) == false)
+  else if (matchesRequiredSBMLNamespacesForAddition(static_cast<const SBase *>(p)) == false)
   {
     return LIBSBML_NAMESPACES_MISMATCH;
   }
@@ -628,7 +628,7 @@ KineticLaw::addLocalParameter (const LocalParameter* p)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
-  else if (matchesSBMLNamespaces(static_cast<const SBase *>(p)) == false)
+  else if (matchesRequiredSBMLNamespacesForAddition(static_cast<const SBase *>(p)) == false)
   {
     return LIBSBML_NAMESPACES_MISMATCH;
   }
@@ -1202,6 +1202,22 @@ KineticLaw::divideAssignmentsToSIdByFunction(const std::string& id, const ASTNod
 }
 /** @endcond */
 
+/** @cond doxygen-libsbml-internal */
+void 
+KineticLaw::multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function)
+{
+  SBase* parentrxn = getParentSBMLObject();
+  if (parentrxn==NULL) return;
+  if (parentrxn->getId() == id && isSetMath()) {
+    ASTNode* temp = mMath;
+    mMath = new ASTNode(AST_TIMES);
+    mMath->addChild(temp);
+    mMath->addChild(function->deepCopy());
+  }
+}
+/** @endcond */
+
+
 /** @cond doxygen-libsbml-internal */
 /*
  * @return the ordinal position of the element with respect to its siblings
@@ -1888,7 +1904,7 @@ KineticLaw_isSetSubstanceUnits (const KineticLaw_t *kl)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -1928,7 +1944,7 @@ KineticLaw_setFormula (KineticLaw_t *kl, const char *formula)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -1955,7 +1971,7 @@ KineticLaw_setMath (KineticLaw_t *kl, const ASTNode_t *math)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1990,7 +2006,7 @@ KineticLaw_setTimeUnits (KineticLaw_t *kl, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -2022,7 +2038,7 @@ KineticLaw_setSubstanceUnits (KineticLaw_t *kl, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2049,7 +2065,7 @@ KineticLaw_unsetTimeUnits (KineticLaw_t *kl)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2079,7 +2095,7 @@ KineticLaw_unsetSubstanceUnits (KineticLaw_t *kl)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_LEVEL_MISMATCH
@@ -2108,7 +2124,7 @@ KineticLaw_addParameter (KineticLaw_t *kl, const Parameter_t *p)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_LEVEL_MISMATCH
