@@ -127,6 +127,7 @@ SBMLDocument::SBMLDocument (unsigned int level, unsigned int version) :
  , mLevel   ( level   )
  , mVersion ( version )
  , mModel   ( NULL       )
+ , mLocationURI     ("")
 {
 
   mInternalValidator = new SBMLInternalValidator();
@@ -157,8 +158,9 @@ SBMLDocument::SBMLDocument (unsigned int level, unsigned int version) :
 
 
 SBMLDocument::SBMLDocument (SBMLNamespaces* sbmlns) :
-   SBase (sbmlns)
- , mModel   ( NULL       )
+   SBase  (sbmlns)
+ , mModel ( NULL       )
+ , mLocationURI ("")
 {
 
   mInternalValidator = new SBMLInternalValidator();
@@ -240,8 +242,9 @@ SBMLDocument::~SBMLDocument ()
  * Creates a copy of this SBMLDocument.
  */
 SBMLDocument::SBMLDocument (const SBMLDocument& orig) :
-   SBase    ( orig          )
- , mModel   ( NULL             )
+   SBase  ( orig          )
+ , mModel ( NULL          )
+ , mLocationURI (orig.mLocationURI )
 {
   if (&orig == NULL)
   {
@@ -293,6 +296,7 @@ SBMLDocument& SBMLDocument::operator=(const SBMLDocument& rhs)
 
     mLevel                             = rhs.mLevel;
     mVersion                           = rhs.mVersion;
+    mLocationURI                       = rhs.mLocationURI;
 
     mInternalValidator = (SBMLInternalValidator*)rhs.mInternalValidator->clone();
     mInternalValidator->setDocument(this);
@@ -608,6 +612,9 @@ SBMLDocument::setModel (const Model* m)
     mModel = (m != NULL) ? new Model(*m) : NULL;
 
     if (mModel != NULL) mModel->connectToParent(this);
+    if (getURI() != mModel->getURI()) {
+      mModel->setElementNamespace(getURI());
+    }
     
     return LIBSBML_OPERATION_SUCCESS;
   }
@@ -646,6 +653,20 @@ SBMLDocument::createModel (const std::string& sid)
 }
 
 
+void 
+SBMLDocument::setLocationURI (const std::string& uri)
+{
+  mLocationURI = uri;
+}
+
+
+std::string 
+SBMLDocument::getLocationURI()
+{
+  return mLocationURI;
+}
+
+
 void 
 SBMLDocument::setConsistencyChecks(SBMLErrorCategory_t category,
                                    bool apply)
@@ -687,7 +708,7 @@ SBMLDocument::checkConsistency ()
   return numErrors;
 }
 
-/**
+/*
  * Performs consistency checking and validation on this SBML document.
  *
  * If this method returns a nonzero value (meaning, one or more
@@ -976,7 +997,7 @@ SBMLDocument::createObject (XMLInputStream& stream)
 /** @endcond */
 
 
-/**
+/*
   * @return the Namespaces associated with this SBML object
   */
 XMLNamespaces* 
@@ -1173,7 +1194,7 @@ SBMLDocument::isSetPkgRequired(const std::string& package)
   return isSetPackageRequired(package);
 }
 
-/**
+/*
  * Returnes @c true if the given package extension is one of ignored
  * packages (i.e. the package is defined in this document but the package
  * is not available), otherwise returns @c false.
@@ -1181,7 +1202,7 @@ SBMLDocument::isSetPkgRequired(const std::string& package)
 bool 
 SBMLDocument::isIgnoredPackage(const std::string& pkgURI)
 {
-  if (isSetPkgRequired(pkgURI) && !isPkgURIEnabled(pkgURI))
+  if (isSetPackageRequired(pkgURI) && !isPackageURIEnabled(pkgURI))
     return true;
 
   return false;
@@ -1195,7 +1216,7 @@ SBMLDocument::isIgnoredPkg(const std::string& pkgURI)
 
 /** @cond doxygen-libsbml-internal */
 
-/**
+/*
  * Subclasses should override this method to get the list of
  * expected attributes.
  * This function is invoked from corresponding readAttributes()
@@ -1582,7 +1603,7 @@ SBMLDocument::writeAttributes (XMLOutputStream& stream) const
 }
 
 
-/**
+/*
  *
  * Subclasses should override this method to write their xmlns attriubutes
  * (if any) to the XMLOutputStream.  Be sure to call your parents implementation
@@ -1667,7 +1688,7 @@ SBMLDocument::writeElements (XMLOutputStream& stream) const
 }
 
 
-/**
+/*
  * Enables/Disables the given package with this element and child
  * elements (if any).
  * (This is an internal implementation for enablePackage function)
@@ -2094,7 +2115,7 @@ SBMLDocument_setLevelAndVersionNonStrict (  SBMLDocument_t *d
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_LEVEL_MISMATCH
@@ -2123,6 +2144,21 @@ SBMLDocument_createModel (SBMLDocument_t *d)
   return (d != NULL) ? d->createModel() : NULL;
 }
 
+LIBSBML_EXTERN
+void 
+SBMLDocument_setLocationURI (SBMLDocument_t *d, const std::string& location)
+{
+  if (d != NULL) d->setLocationURI(location);
+}
+
+LIBSBML_EXTERN
+char*
+SBMLDocument_getLocationURI(SBMLDocument_t *d)
+{
+  return (d != NULL) ? safe_strdup( d->getLocationURI().c_str() ) : NULL;
+}
+
+
 /**
  * Allows particular validators to be turned on or off prior to
  * calling checkConsistency. 
