@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2009-2011 jointly by the following organizations: 
+ * Copyright (C) 2009-2012 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
  *  
@@ -56,7 +56,7 @@
  * (e.g., using SBMLDocument::getNumErrors()), access the Model object, and
  * perform other actions such as consistency-checking and model
  * translation.
- * @endif
+ * @endif@~
  * 
  * When creating fresh models programmatically, the starting point is
  * typically the creation of an SBMLDocument object instance.  The
@@ -136,55 +136,43 @@
  * that they may not be interested by calling
  * SBMLDocument::setConsistencyChecks(int categ, boolean onoff) with
  * appropriate parameters.
- * @endif
+ * @endif@~
  *
  * These methods have slightly different relevance depending on whether a
  * model is created programmaticaly from scratch, or whether it is read in
- * from a file or data stream.  The following table summarizes the possible
+ * from a file or data stream.  The following list summarizes the possible
  * scenarios.
  *
- * <center>
- * <table border="0" class="text-table width80 normal-font alt-row-colors">
- *  <tr style="background: lightgray; font-size: 14px;">
- *      <th align="left" width="200">Scenario</th>
- *      <th align="left">Relevant methods</th>
- *  </tr>
- * <tr><td>Creating a model from scratch</td>
- * <td>Before writing out the model:<ol>
+ * <em>Scenario 1: Creating a model from scratch</em>.  Before writing out
+ * the model, 
+ *
+ * @li Call SBMLDocument::checkInternalConsistency(), then inquire about
+ * the results by calling SBMLDocument::getNumErrors()
+ *
+ * @li Call @if java SBMLDocument::setConsistencyChecks(int categ, boolean
+ * onoff) @else SBMLDocument::setConsistencyChecks() @endif@~ to configure
+ * which checks will be performed by SBMLDocument::checkConsistency()
+ *
+ * @li Call SBMLDocument::checkConsistency(), then inquire about the results by
+ * calling SBMLDocument::getNumErrors()
+ *
+ * <em>Scenario 2: Reading a model from a file or data stream.</em> After
+ * reading the model,
  * 
- * <li style="margin-bottom: 0.5em">Call
- * SBMLDocument::checkInternalConsistency(), then inquire about the results by
- * calling SBMLDocument::getNumErrors()</li>
+ * @li Basic consistency checks will have been performed automatically by
+ * libSBML upon reading the content, so you only need to inquire about the
+ * results by using SBMLDocument::getNumErrors()
  * 
- * <li style="margin-bottom: 0.5em">
- * Call @if java SBMLDocument::setConsistencyChecks(int categ, boolean onoff) @else SBMLDocument::setConsistencyChecks() @endif to configure which checks
- * will be performed by SBMLDocument::checkConsistency()</li>
+ * @li Call @if java SBMLDocument::setConsistencyChecks(int categ, boolean
+ * onoff) @else SBMLDocument::setConsistencyChecks() @endif@~ to configure
+ * which checks are performed by SBMLDocument::checkConsistency()
  * 
- * <li>Call SBMLDocument::checkConsistency(), then inquire about the results by
- * calling SBMLDocument::getNumErrors()</li>
- * </ol>
- * </td>
- * <tr><td>Reading a model from a file or data stream</td>
- * <td>After reading the model:<ol>
- * 
- * <li style="margin-bottom: 0.5em">Basic consistency checks will have been
- * performed automatically by libSBML upon reading the content&mdash;only need
- * to inquire about the results by using SBMLDocument::getNumErrors()</li>
- * 
- * <li style="margin-bottom: 0.5em">
- * Call @if java SBMLDocument::setConsistencyChecks(int categ, boolean onoff) @else SBMLDocument::setConsistencyChecks() @endif to configure which
- * checks are performed by SBMLDocument::checkConsistency()</li>
- * 
- * <li>Call SBMLDocument::checkConsistency(), then inquire about the results
- * by calling SBMLDocument::getNumErrors()</li>
- * </ol>
- * </td>
- * </table>
- * </center>
+ * @li Call SBMLDocument::checkConsistency(), then inquire about the results
+ * by calling SBMLDocument::getNumErrors()
  *
  * @if clike An example of using the consistency-checking
  * and validation facilities is provided in this manual in the
- * section @ref libsbml-example. @endif
+ * section @ref libsbml-example. @endif@~
  * 
  * @section converting Converting documents between Levels and Versions of SBML
  *
@@ -197,11 +185,11 @@
  * can be translated downward as well, if they do not use constructs
  * specific to more advanced Levels of SBML.
  *
- * Calling @if java SBMLDocument::setLevelAndVersion(long lev, long ver, boolean strict) @else SBMLDocument::setLevelAndVersion() @endif will not @em necessarily lead
+ * Calling @if java SBMLDocument::setLevelAndVersion(long lev, long ver, boolean strict) @else SBMLDocument::setLevelAndVersion() @endif@~ will not @em necessarily lead
  * to a successful conversion.  The method will return a boolean value
  * to indicate success or failure.  Callers must check the error log (see 
  * next section) attached to the SBMLDocument object after calling
- * @if java SBMLDocument::setLevelAndVersion(long lev, long ver) @else SBMLDocument::setLevelAndVersion() @endif in order to assess whether any
+ * @if java SBMLDocument::setLevelAndVersion(long lev, long ver) @else SBMLDocument::setLevelAndVersion() @endif@~ in order to assess whether any
  * problems arose.
  *
  * If an application is interested in translating to a lower Level and/or
@@ -241,7 +229,7 @@
  * reported through a single common interface involving the object class
  * SBMLError.
  *
- * The methods SBMLDocument::getNumErrors(), @if java SBMLDocument::getError(long n) @else SBMLDocument::getError() @endif and
+ * The methods SBMLDocument::getNumErrors(), @if java SBMLDocument::getError(long n) @else SBMLDocument::getError() @endif@~ and
  * SBMLDocument::printErrors() allow callers to interact with the warnings
  * or errors logged.  Alternatively, callers may retrieve the entire log as
  * an SBMLErrorLog object using the method SBMLDocument::getErrorLog().
@@ -256,7 +244,7 @@
  *
  * @if clike An example of using the error facility is
  * provided in this manual in the
- * section @ref libsbml-example. @endif
+ * section @ref libsbml-example. @endif@~
  * 
  */
 
@@ -285,10 +273,8 @@ class ConversionProperties;
 class SBMLVisitor;
 class XMLError;
 
-#ifndef DONT_USE_VALIDATOR_API
 class SBMLValidator;
 class SBMLInternalValidator;
-#endif
 
 /** @cond doxygen-libsbml-internal */
 /* Internal constants for setting/unsetting particular consistency checks. */
@@ -326,8 +312,15 @@ public:
    * specified at the time of the construction of an SBMLDocument instance.
    *
    * @return an integer indicating the most recent SBML specification Level
+   *
+   * @if notclike @note Because this is a @em static method, the
+   * non-C++ language interfaces for libSBML will contain two variants.  One
+   * will be a static method on the class (i.e., SBMLDocument), and the
+   * other will be a standalone top-level function with the name
+   * SBMLDocument_getDefaultLevel(). They are functionally
+   * identical. @endif@~
    * 
-   * @see getDefaultVersion()
+   * @see @if clike getDefaultVersion() @else SBMLDocument::getDefaultVersion() @endif@~
    */
   static unsigned int getDefaultLevel ();
 
@@ -346,7 +339,14 @@ public:
    * @return an integer indicating the most recent SBML specification
    * Version
    *
-   * @see getDefaultLevel()
+   * @if notclike @note Because this is a @em static method, the
+   * non-C++ language interfaces for libSBML will contain two variants.  One
+   * will be a static method on the class (i.e., SBMLDocument), and the
+   * other will be a standalone top-level function with the name
+   * SBMLDocument_getDefaultVersion(). They are functionally
+   * identical. @endif@~
+   *
+   * @see @if clike getDefaultLevel() @else SBMLDocument::getDefaultLevel() @endif@~
    */
   static unsigned int getDefaultVersion ();
 
@@ -376,7 +376,12 @@ public:
    *
    * @param version an integer for the Version within the SBML Level
    *
-   * @if notcpp @docnote @htmlinclude warn-default-args-in-docs.html @endif
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the given @p level and @p version combination, or this kind
+   * of SBML object, are either invalid or mismatched with respect to the
+   * parent SBMLDocument object.
+   *
+   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
    *
    * @see SBMLDocument::setLevelAndVersion(@if java long lev, long ver, boolean strict@endif)
    * @see getDefaultLevel()
@@ -384,6 +389,7 @@ public:
    */
   SBMLDocument (unsigned int level = 0, unsigned int version = 0);
 
+
   /**
    * Creates a new SBMLDocument using the given SBMLNamespaces object 
    * @p sbmlns.
@@ -397,6 +403,10 @@ public:
    *
    * @param sbmlns an SBMLNamespaces object.
    *
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the given @p level and @p version combination, or this kind
+   * of SBML object, are either invalid or mismatched with respect to the
+   * parent SBMLDocument object.
    */
   SBMLDocument (SBMLNamespaces* sbmlns);
 
@@ -409,12 +419,23 @@ public:
 
   /**
    * Copy constructor; creates a copy of this SBMLDocument.
+   *
+   * @param orig the object to copy.
+   * 
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the argument @p orig is @c NULL.
    */
-  SBMLDocument (const SBMLDocument& rhs);
+  SBMLDocument (const SBMLDocument& orig);
 
 
   /**
    * Assignment operator for SBMLDocument.
+   *
+   * @param rhs The object whose values are used as the basis of the
+   * assignment.
+   *
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
+   * Thrown if the argument @p rhs is @c NULL.
    */
   SBMLDocument& operator=(const SBMLDocument& rhs);
 
@@ -612,7 +633,7 @@ public:
    * find out whether it is Level&nbsp;1.  (If the conversion to
    * Level&nbsp;1 failed, the Level of this model will be left unchanged.)
    *
-   * @if notcpp @docnote @htmlinclude warn-default-args-in-docs.html @endif
+   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
    * 
    * @see checkL1Compatibility()
    * @see checkL2v1Compatibility()
@@ -627,6 +648,11 @@ public:
 
 
   /** @cond doxygen-libsbml-internal */
+  /**
+   * @param package
+   * @param level
+   * @param version
+   */
   void updateSBMLNamespace(const std::string& package, unsigned int level, 
                            unsigned int version);
   /** @endcond */
@@ -639,7 +665,7 @@ public:
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH @endlink
@@ -662,13 +688,25 @@ public:
    *
    * @param sid the identifier of the new Model to create.
    *
-   * @if notcpp @docnote @htmlinclude warn-default-args-in-docs.html @endif
+   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
    *
    * @see getModel()
    * @see SBMLDocument::setModel(@if java Model m@endif)
    */
   Model* createModel (const std::string& sid = "");
 
+  /**
+   * Sets the location of this SBMLDocument.  Called automatically when
+   * readSBMLFromFile is used, but may be set manually as well.
+   */
+  void setLocationURI (const std::string& uri);
+
+  /**
+   * Get the location of this SBMLDocument.  If this document was 
+   * read from a file or had its location set manually, that filename
+   * or set location will be returned, otherwise, an empty string is returned.
+   */
+  std::string getLocationURI();
 
   /**
    * Controls the consistency checks that are performed when
@@ -697,7 +735,7 @@ public:
    * set of constants whose names begin with the characters <code>LIBSBML_CAT_</code>
    * in the interface class @link libsbml libsbml@endlink.
    * The following are the possible choices:
-   * @endif
+   * @endif@~
    * <ul>
    * <li> @link SBMLErrorCategory_t#LIBSBML_CAT_GENERAL_CONSISTENCY
    * LIBSBML_CAT_GENERAL_CONSISTENCY@endlink: Correctness and consistency
@@ -766,7 +804,7 @@ public:
    * applied.
    * 
    * @param category a value drawn from @if clike #SBMLErrorCategory_t@else
-   * the set of SBML error categories@endif indicating the
+   * the set of SBML error categories@endif@~ indicating the
    * consistency checking/validation to be turned on or off.
    *
    * @param apply a boolean indicating whether the checks indicated by
@@ -805,7 +843,7 @@ public:
    * set of constants whose names begin with the characters <code>LIBSBML_CAT_</code>
    * in the interface class @link libsbml libsbml@endlink.
    * The following are the possible choices:
-   * @endif
+   * @endif@~
    * <ul>
    * <li> @link SBMLErrorCategory_t#LIBSBML_CAT_GENERAL_CONSISTENCY
    * LIBSBML_CAT_GENERAL_CONSISTENCY@endlink: Correctness and consistency
@@ -874,7 +912,7 @@ public:
    * applied.
    * 
    * @param category a value drawn from @if clike #SBMLErrorCategory_t@else
-   * the set of SBML error categories@endif indicating the consistency
+   * the set of SBML error categories@endif@~ indicating the consistency
    * checking/validation to be turned on or off.
    *
    * @param apply a boolean indicating whether the checks indicated by
@@ -901,6 +939,24 @@ public:
    */
   unsigned int checkConsistency ();
 
+  /**
+   * Performs consistency checking and validation on this SBML document.
+   *
+   * If this method returns a nonzero value (meaning, one or more
+   * consistency checks have failed for SBML document), the failures may be
+   * due to warnings @em or errors.  Callers should inspect the severity
+   * flag in the individual SBMLError objects returned by
+   * SBMLDocument::getError(@if java long n@endif) to determine the nature of the failures.
+   *
+   * @note unlike checkConsistency this method will write the document
+   *       in order to determine all errors for the document. This will 
+   *       also clear the error log. 
+   *
+   * @return the number of failed checks (errors) encountered.
+   *
+   * @see SBMLDocument::checkConsistency()
+   */
+  unsigned int validateSBML ();
 
   /**
    * Performs consistency checking on libSBML's internal representation of 
@@ -1032,9 +1088,12 @@ public:
 
 
   /**
-   * Prints to the given output stream all the errors or warnings
-   * encountered during parsing, consistency checking, or attempted
-   * translation of this model.
+   * Prints all the errors or warnings encountered trying to parse,
+   * check, or translate this SBML document.
+   *
+   * It prints the text to the stream given by the optional parameter @p
+   * stream.  If no parameter is given, it prints the output to the
+   * standard error stream.
    *
    * If no errors have occurred, i.e., <code>getNumErrors() == 0</code>, no
    * output will be sent to the stream.
@@ -1045,7 +1104,14 @@ public:
      line NNN: (id) message
  @endverbatim
    *
-   * @if notcpp @docnote @htmlinclude warn-default-args-in-docs.html @endif
+   * @param stream the ostream or ostringstream object indicating where
+   * the output should be printed.
+   *
+   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   *
+   * @see getNumErrors()
+   * @see getErrorLog()
+   * @see SBMLDocument::getError(unsigned int n)
    */
   void printErrors (std::ostream& stream = std::cerr) const;
 
@@ -1081,7 +1147,7 @@ public:
    * 
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED  @endlink
@@ -1126,7 +1192,7 @@ public:
    * codes</em>.  In the C# language interface for libSBML, the type codes
    * are defined as static integer constants in the interface class @link
    * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
+   * the characters @c SBML_. @endif@~
    *
    * @return the SBML type code for this object, or @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
    *
@@ -1155,6 +1221,18 @@ public:
   SBMLErrorLog* getErrorLog ();
 
 
+  /**
+   * Returns a constant pointer to the list of errors or warnings 
+   * logged during parsing, consistency checking, or attempted translation 
+   * of this model.
+   * 
+   * @return the SBMLErrorLog used for this SBMLDocument
+   * 
+   * @see SBMLDocument::getNumErrors()
+   */
+  const SBMLErrorLog* getErrorLog () const;
+
+
   /**
    * Returns a list of XML Namespaces associated with the XML content
    * of this SBML document.
@@ -1165,17 +1243,20 @@ public:
 
 
   /**
-   * Set/Unset default namespace (i.e. add xmlns="..." attribute) to
-   * each top level element defined in the given package extension.
-   * No prefix will be written when writing elements defined in the
-   * given package extension if "true" is given as second argument.
+   * Set/unset default namespace to each top-level element defined in the
+   * given package extension.
+   *
+   * This works by adding a <code>xmlns=&quot;...&quot;</code> attribute.  No
+   * prefix will be written when writing elements defined in the given
+   * package extension if @c true is given as second argument.
    *
    * @param package the name or URI of the package extension.
-   * @param flag bool value
+   * @param flag boolean value to indicate whether to write a namespace
+   * prefix.
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_PKG_UNKNOWN_VERSION LIBSBML_PKG_UNKNOWN_VERSION @endlink
@@ -1184,9 +1265,12 @@ public:
 
 
   /**
-   * Returns @c true if a default namespace (i.e. add xmlns="..." attribute) 
-   * is added to each top level element defined in the given package extension,
-   * otherwise returns @c false.
+   * Returns @c true if a default namespace is added to each top-level
+   * element defined in the given package extension, otherwise returns
+   * @c false.
+   *
+   * This basically checks if the attribute
+   * <code>xmlns=&quot;...&quot;</code> is present.
    *   
    * @param package the name or URI of the package extension.
    *
@@ -1196,17 +1280,18 @@ public:
 
   
   /**
-   * Sets the required attribute of the given package extension.
+   * Sets the <code>required</code> attribute value of the given package
+   * extension.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
-   * @param flag bool value
+   * @param flag Boolean value indicating whether the package is required.
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_PKG_UNKNOWN_VERSION LIBSBML_PKG_UNKNOWN_VERSION @endlink
@@ -1215,57 +1300,62 @@ public:
 
 
   /**
-   * Returnes the required attribute of the given package extension.
+   * Returns the <code>required</code> attribute of the given package
+   * extension.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
    *
-   * @return boolean flag indicating whether the package is flagged as
+   * @return Boolean flag indicating whether the package is flagged as
    * being required.
    */
   bool getPackageRequired(const std::string& package);
 
 
   /**
-   * Returnes @c true if the required attribute of the given package extension
+   * Returns @c true if the required attribute of the given package extension
    * is defined, otherwise returns @c false.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
    *
-   * @return a boolean
+   * @return a Boolean
    */
   bool isSetPackageRequired(const std::string& package);
 
 
   /**
-   * Returnes @c true if the given package extension is one of ignored
-   * packages (i.e. the package is defined in this document but the package
-   * is not available), otherwise returns @c false.
+   * Returns @c true if the given package extension is one of an ignored
+   * packages, otherwise returns @c false.
+   *
+   * An ignored package is one that is defined to be used in this SBML
+   * document, but the package is not enabled in this copy of libSBML.
    *
    * @param pkgURI the URI of the package extension.
    *
-   * @return a boolean
+   * @return a Boolean, @c true if the package is being ignored and
+   * @c false otherwise.
    */
   bool isIgnoredPackage(const std::string& pkgURI);
   
   
   /**
-   * Sets the required attribute of the given package extension.
+   * Sets the value of the <code>required</code> attribute for the given
+   * package.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
-   * @param flag bool value
+   * @param flag a Boolean value.
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_PKG_UNKNOWN_VERSION LIBSBML_PKG_UNKNOWN_VERSION @endlink
@@ -1277,15 +1367,16 @@ public:
 
 
   /**
-   * Returnes the required attribute of the given package extension.
+   * Returns the <code>required</code> attribute of the given package
+   * extension.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
    *
-   * @return boolean flag indicating whether the package is flagged as
-   * being required.
+   * @return a Boolean value indicating whether the package is flagged as
+   * being required in this SBML document.
    *
    * @deprecated Replaced in libSBML 5.2.0 by
    * getPackageRequired(@if java String package flag@endif)
@@ -1294,15 +1385,15 @@ public:
 
 
   /**
-   * Returnes @c true if the required attribute of the given package extension
+   * Returns @c true if the required attribute of the given package extension
    * is defined, otherwise returns @c false.
    *
-   * @note the name of package must not be given if the package is
-   *       not enabled.
+   * @note The name of package must not be given if the package is not
+   * enabled.
    *
    * @param package the name or URI of the package extension.
    *
-   * @return a boolean
+   * @return a Boolean value.
    *
    * @deprecated Replaced in libSBML 5.2.0 by
    * isSetPackageRequired(@if java String package flag@endif)
@@ -1311,19 +1402,21 @@ public:
 
 
   /**
-   * Returnes @c true if the given package extension is one of ignored
-   * packages (i.e. the package is defined in this document but the package
-   * is not available), otherwise returns @c false.
+   * Returns @c true if the given package extension is one of ignored
+   * packages, otherwise returns @c false.
+   *
+   * An ignored package is one that is defined to be used in this SBML
+   * document, but the package is not enabled in this copy of libSBML.
    *
    * @param pkgURI the URI of the package extension.
    *
    * @return a boolean
    *
    * @deprecated Replaced in libSBML 5.2.0 by
-   * isIgnoredPkg(@if java String pkgURI flag@endif)
+   * isIgnoredPackage(@if java String pkgURI flag@endif)
    */
   bool isIgnoredPkg(const std::string& pkgURI);
-  
+
 
   /** @cond doxygen-libsbml-internal */
   /**
@@ -1367,8 +1460,6 @@ public:
   void setConversionValidators(unsigned char appl);
 
 
-#ifndef DONT_USE_VALIDATOR_API
-
   /**
    * Validation system.
    */
@@ -1392,8 +1483,6 @@ public:
    */
   SBMLValidator* getValidator(unsigned int index);
 
-#endif
-
   /** @endcond */
 
 
@@ -1452,16 +1541,12 @@ protected:
   int mVersion;
 
   Model* mModel;
+  std::string mLocationURI;
 
   SBMLErrorLog mErrorLog;
 
-#ifdef DONT_USE_VALIDATOR_API
-  unsigned char mApplicableValidators;
-  unsigned char mApplicableValidatorsForConversion;
-#else
   std::list<SBMLValidator*> mValidators;
   SBMLInternalValidator *mInternalValidator;
-#endif
 
   //PkgRequiredMap           mPkgRequiredMap;
   XMLAttributes            mRequiredAttrOfUnknownPkg;
@@ -1570,6 +1655,14 @@ LIBSBML_EXTERN
 Model_t *
 SBMLDocument_createModel (SBMLDocument_t *d);
 
+LIBSBML_EXTERN
+void 
+SBMLDocument_setLocationURI (SBMLDocument_t *d, const char* location);
+
+LIBSBML_EXTERN
+char*
+SBMLDocument_getLocationURI(SBMLDocument_t *d);
+
 LIBSBML_EXTERN
 void
 SBMLDocument_setConsistencyChecks(SBMLDocument_t *d, 
@@ -1587,6 +1680,11 @@ unsigned int
 SBMLDocument_checkConsistency (SBMLDocument_t *d);
 
 
+LIBSBML_EXTERN
+unsigned int
+SBMLDocument_validateSBML (SBMLDocument_t *d);
+
+
 LIBSBML_EXTERN
 unsigned int
 SBMLDocument_checkInternalConsistency (SBMLDocument_t *d);
@@ -1634,12 +1732,13 @@ SBMLDocument_printErrors (SBMLDocument_t *d, FILE *stream);
 
 LIBSBML_EXTERN
 unsigned int
-SBMLDocument_getDefaultLevel (void);
+SBMLDocument_getDefaultLevel ();
 
 
 LIBSBML_EXTERN
 unsigned int
-SBMLDocument_getDefaultVersion (void);
+SBMLDocument_getDefaultVersion ();
+
 
 LIBSBML_EXTERN
 const XMLNamespaces_t *
