@@ -90,6 +90,7 @@ SBMLNamespaces::initSBMLNamespace()
   {
     mLevel = SBML_INT_MAX;
     mVersion = SBML_INT_MAX;
+    delete mNamespaces;
     mNamespaces = NULL;
   }
 }
@@ -326,11 +327,13 @@ SBMLNamespaces::getNamespaces() const
 }
 
 
-void
+int
 SBMLNamespaces::addNamespaces(const XMLNamespaces * xmlns)
 {
+  int success = LIBSBML_OPERATION_SUCCESS;
+
   if (xmlns == NULL)
-    return;
+    return LIBSBML_INVALID_OBJECT;
 
   if (!mNamespaces) 
   {
@@ -344,9 +347,11 @@ SBMLNamespaces::addNamespaces(const XMLNamespaces * xmlns)
   {
     if (!(mNamespaces->hasNS(xmlns->getURI(i), xmlns->getPrefix(i))))
     {
-      mNamespaces->add(xmlns->getURI(i), xmlns->getPrefix(i));
+      success = mNamespaces->add(xmlns->getURI(i), xmlns->getPrefix(i));
     }
   }
+
+  return success;
 }
 
 /*
@@ -450,7 +455,7 @@ SBMLNamespaces::addPkgNamespaces (const XMLNamespaces *xmlns)
 }
 /** @endcond */
 
-void
+int
 SBMLNamespaces::addNamespace(const std::string &uri, const std::string &prefix)
 {
   if (!mNamespaces) 
@@ -458,7 +463,7 @@ SBMLNamespaces::addNamespace(const std::string &uri, const std::string &prefix)
     initSBMLNamespace();
   }
 
-  mNamespaces->add(uri, prefix);
+  return mNamespaces->add(uri, prefix);
 }
 
 
@@ -770,18 +775,8 @@ SBMLNamespaces::setNamespaces(XMLNamespaces * xmlns)
  * @param version the SBML version
  *
  * @return SBMLNamespaces_t structure created
- * 
- * @docnote The native C++ implementation of this method defines a
- * default argument value.  In the documentation generated for different
- * libSBML language bindings, you may or may not see corresponding
- * arguments in the method declarations.  For example, in Java, a default
- * argument is handled by declaring two separate methods, with one of
- * them having the argument and the other one lacking the argument.
- * However, the libSBML documentation will be @em identical for both
- * methods.  Consequently, if you are reading this and do not see an
- * argument even though one is described, please look for descriptions of
- * other variants of this method near where this one appears in the
- * documentation.
+ *
+ * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
  */
 
 LIBSBML_EXTERN
@@ -863,12 +858,14 @@ SBMLNamespaces_getSBMLNamespaceURI(unsigned int level, unsigned int version)
  * @param xmlns the XML namespaces to be added.
  */
 LIBSBML_EXTERN
-void
+int
 SBMLNamespaces_addNamespaces(SBMLNamespaces_t *sbmlns,
                              const XMLNamespaces_t * xmlns)
 {
   if (sbmlns != NULL)
-    sbmlns->addNamespaces(xmlns);
+    return sbmlns->addNamespaces(xmlns);
+  else
+    return LIBSBML_INVALID_OBJECT;
 }
 
 /**
