@@ -25,8 +25,13 @@
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ---------------------------------------------------------------------- -->*/
 
-#include <sbml/SBMLTypes.h>
 #include <sbml/SBMLVisitor.h>
+#include <sbml/SBMLDocument.h>
+#include <sbml/Model.h>
+#include <sbml/AlgebraicRule.h>
+#include <sbml/AssignmentRule.h>
+#include <sbml/RateRule.h>
+#include <sbml/ModifierSpeciesReference.h>
 
 LIBSBML_CPP_NAMESPACE_BEGIN
 
@@ -261,6 +266,12 @@ SBMLVisitor::leave (const Reaction& x)
 }
 
 
+void
+SBMLVisitor::leave (const SBase& x)
+{
+}
+
+
 void
 SBMLVisitor::leave (const ListOf& x, int type)
 {
