@@ -119,9 +119,9 @@ SBO::readTerm (const XMLAttributes& attributes, SBMLErrorLog* log,
  * Writes sboTerm as an XMLAttribute to the given XMLOutputStream.
  */
 void
-SBO::writeTerm (XMLOutputStream& stream, int sboTerm)
+SBO::writeTerm (XMLOutputStream& stream, int sboTerm, const std::string& prefix)
 {
-  stream.writeAttribute( "sboTerm", intToString(sboTerm) );
+  stream.writeAttribute( "sboTerm", prefix, intToString(sboTerm) );
 }
 /** @endcond */
 
@@ -179,7 +179,7 @@ SBO::intToString (int sboTerm)
   * functions for checking the SBO term is from correct part of SBO
   * Unary Functor returns the parent portion of a ParentMap pair.
   */
-struct GetParent : public unary_function<const pair<const int, int>, int>
+struct GetSecond : public unary_function<const pair<const int, int>, int>
 {
   int operator() (const pair<const int, int>& pair) { return pair.second; }
 };
@@ -203,7 +203,7 @@ SBO::isChildOf(unsigned int term, unsigned int parent)
 
 
   // Copy parents of term to nodes.
-  transform(range.first, range.second, back_inserter(nodes), GetParent());
+  transform(range.first, range.second, back_inserter(nodes), GetSecond());
 
   // Search nodes DFS for parent.
   // (For BFS, change back() and pop_back() to front() and pop_front().)
@@ -220,7 +220,7 @@ SBO::isChildOf(unsigned int term, unsigned int parent)
 
     // Copy parents of p to nodes and continue search.
     range = mParent.equal_range(p);
-    transform(range.first, range.second, back_inserter(nodes), GetParent());
+    transform(range.first, range.second, back_inserter(nodes), GetSecond());
   }
 
   return result;
@@ -663,7 +663,7 @@ SBO::isObselete  (unsigned int sboTerm)
 void
 SBO::populateSBOTree()
 {
-  // generated from SBO on August 18th, 2011
+  // generated from SBO on July 19th 2012
   mParent.insert( pair<const int, int>(  1,  64) );
   mParent.insert( pair<const int, int>(  2, 545) );
   mParent.insert( pair<const int, int>(  3,   0) );
@@ -1186,7 +1186,7 @@ SBO::populateSBOTree()
   mParent.insert( pair<const int, int>(470, 540) );
   mParent.insert( pair<const int, int>(471, 196) );
   mParent.insert( pair<const int, int>(472, 196) );
-  mParent.insert( pair<const int, int>(473, 374) );
+  mParent.insert( pair<const int, int>(473, 552) );
   mParent.insert( pair<const int, int>(474,  64) );
   mParent.insert( pair<const int, int>(475, 474) );
   mParent.insert( pair<const int, int>(476, 347) );
@@ -1297,6 +1297,11 @@ SBO::populateSBOTree()
   mParent.insert( pair<const int, int>(581, 580) );
   mParent.insert( pair<const int, int>(582, 581) );
   mParent.insert( pair<const int, int>(583, 581) );
+  mParent.insert( pair<const int, int>(584, 346) );
+  mParent.insert( pair<const int, int>(585, 347) );
+  mParent.insert( pair<const int, int>(586, 346) );
+  mParent.insert( pair<const int, int>(587, 185) );
+  mParent.insert( pair<const int, int>(588, 185) );
 
 
 
