@@ -224,9 +224,9 @@ public:
     unsigned int column = 0);
 
   /**
-   * Writes sboTerm as an XMLAttribute to the given XMLOutputStream.
+   * Writes sboTerm as an XMLAttribute with the given prefix to the given XMLOutputStream.
    */
-  static void writeTerm (XMLOutputStream& stream, int sboTerm);
+  static void writeTerm (XMLOutputStream& stream, int sboTerm, const std::string& prefix = "");
 
   /** @endcond */
 
@@ -241,7 +241,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isQuantitativeParameter(). They are functionally identical. @endif
+   * SBO_isQuantitativeParameter(). They are functionally identical. @endif@~
    */
   static bool isQuantitativeParameter  (unsigned int term);
 
@@ -255,7 +255,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isParticipantRole(). They are functionally identical. @endif
+   * SBO_isParticipantRole(). They are functionally identical. @endif@~
    */
   static bool isParticipantRole  (unsigned int term);
 
@@ -269,7 +269,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isModellingFramework(). They are functionally identical. @endif
+   * SBO_isModellingFramework(). They are functionally identical. @endif@~
    */
   static bool isModellingFramework  (unsigned int term);
 
@@ -283,7 +283,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isMathematicalExpression(). They are functionally identical. @endif
+   * SBO_isMathematicalExpression(). They are functionally identical. @endif@~
    */
   static bool isMathematicalExpression  (unsigned int term);
 
@@ -297,7 +297,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isKineticConstant(). They are functionally identical. @endif
+   * SBO_isKineticConstant(). They are functionally identical. @endif@~
    */
   static bool isKineticConstant  (unsigned int term);
 
@@ -311,7 +311,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isReactant(). They are functionally identical. @endif
+   * SBO_isReactant(). They are functionally identical. @endif@~
    */
   static bool isReactant  (unsigned int term);
 
@@ -325,7 +325,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isProduct(). They are functionally identical. @endif
+   * SBO_isProduct(). They are functionally identical. @endif@~
    */
   static bool isProduct  (unsigned int term);
 
@@ -339,7 +339,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isModifier(). They are functionally identical. @endif
+   * SBO_isModifier(). They are functionally identical. @endif@~
    */
   static bool isModifier  (unsigned int term);
 
@@ -353,7 +353,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isRateLaw(). They are functionally identical. @endif
+   * SBO_isRateLaw(). They are functionally identical. @endif@~
    */
   static bool isRateLaw  (unsigned int term);
 
@@ -367,7 +367,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isEvent(). They are functionally identical. @endif
+   * SBO_isEvent(). They are functionally identical. @endif@~
    */
   static bool isEvent  (unsigned int term);
 
@@ -381,7 +381,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isPhysicalParticipant(). They are functionally identical. @endif
+   * SBO_isPhysicalParticipant(). They are functionally identical. @endif@~
     */
   static bool isPhysicalParticipant  (unsigned int term);
 
@@ -395,7 +395,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isParticipant(). They are functionally identical. @endif
+   * SBO_isParticipant(). They are functionally identical. @endif@~
     */
   static bool isParticipant  (unsigned int term);
 
@@ -409,7 +409,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isInteraction(). They are functionally identical. @endif
+   * SBO_isInteraction(). They are functionally identical. @endif@~
    */
   static bool isInteraction  (unsigned int term);
 
@@ -423,7 +423,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isEntity(). They are functionally identical. @endif
+   * SBO_isEntity(). They are functionally identical. @endif@~
    */
   static bool isEntity  (unsigned int term);
 
@@ -437,7 +437,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isFunctionalEntity(). They are functionally identical. @endif
+   * SBO_isFunctionalEntity(). They are functionally identical. @endif@~
    */
   static bool isFunctionalEntity  (unsigned int term);
 
@@ -451,7 +451,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isMaterialEntity(). They are functionally identical. @endif
+   * SBO_isMaterialEntity(). They are functionally identical. @endif@~
    */
   static bool isMaterialEntity  (unsigned int term);
 
@@ -465,7 +465,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isConservationLaw(). They are functionally identical. @endif
+   * SBO_isConservationLaw(). They are functionally identical. @endif@~
    */
   static bool isConservationLaw  (unsigned int term);
 
@@ -479,7 +479,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isSteadyStateExpression(). They are functionally identical. @endif
+   * SBO_isSteadyStateExpression(). They are functionally identical. @endif@~
    */
   static bool isSteadyStateExpression  (unsigned int term);
 
@@ -493,7 +493,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isFunctionalCompartment(). They are functionally identical. @endif
+   * SBO_isFunctionalCompartment(). They are functionally identical. @endif@~
    */
   static bool isFunctionalCompartment  (unsigned int term);
 
@@ -507,7 +507,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isContinuousFramework(). They are functionally identical. @endif
+   * SBO_isContinuousFramework(). They are functionally identical. @endif@~
    */
   static bool isContinuousFramework  (unsigned int term);
 
@@ -521,7 +521,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isDiscreteFramework(). They are functionally identical. @endif
+   * SBO_isDiscreteFramework(). They are functionally identical. @endif@~
    */
   static bool isDiscreteFramework  (unsigned int term);
 
@@ -535,7 +535,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isLogicalFramework(). They are functionally identical. @endif
+   * SBO_isLogicalFramework(). They are functionally identical. @endif@~
    */
   static bool isLogicalFramework  (unsigned int term);
 
@@ -549,7 +549,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isMetadataRepresentation(). They are functionally identical. @endif
+   * SBO_isMetadataRepresentation(). They are functionally identical. @endif@~
    */
   static bool isMetadataRepresentation  (unsigned int term);
 
@@ -563,7 +563,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isOccurringEntityRepresentation(). They are functionally identical. @endif
+   * SBO_isOccurringEntityRepresentation(). They are functionally identical. @endif@~
    */
   static bool isOccurringEntityRepresentation  (unsigned int term);
 
@@ -577,7 +577,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isPhysicalEntityRepresentation(). They are functionally identical. @endif
+   * SBO_isPhysicalEntityRepresentation(). They are functionally identical. @endif@~
    */
   static bool isPhysicalEntityRepresentation  (unsigned int term);
 
@@ -591,7 +591,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isSystemsDescriptionParameter(). They are functionally identical. @endif
+   * SBO_isSystemsDescriptionParameter(). They are functionally identical. @endif@~
    */
   static bool isSystemsDescriptionParameter  (unsigned int term);
 
@@ -605,7 +605,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_isObselete(). They are functionally identical. @endif
+   * SBO_isObselete(). They are functionally identical. @endif@~
    */
   static bool isObselete  (unsigned int term);
 
@@ -622,7 +622,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_intToString(). They are functionally identical. @endif
+   * SBO_intToString(). They are functionally identical. @endif@~
    */
   static std::string intToString (int sboTerm);
 
@@ -638,7 +638,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_stringToInt(). They are functionally identical. @endif
+   * SBO_stringToInt(). They are functionally identical. @endif@~
    */
   static int stringToInt (const std::string& sboTerm);
 
@@ -653,7 +653,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_checkTerm(). They are functionally identical. @endif
+   * SBO_checkTerm(). They are functionally identical. @endif@~
    */
   static bool checkTerm (const std::string& sboTerm);
 
@@ -669,7 +669,7 @@ public:
    * non-C++ language interfaces for libSBML will contain two variants.  One
    * will be a static method on the class (i.e., SBO), and the other will
    * be a standalone top-level function with the name
-   * SBO_checkTerm(). They are functionally identical. @endif
+   * SBO_checkTerm(). They are functionally identical. @endif@~
    */
   static bool checkTerm (int sboTerm);
 
