@@ -842,8 +842,24 @@ SpeciesReference::readOtherXML (XMLInputStream& stream)
       delete mCVTerms;
     }
     mCVTerms = new List();
-    RDFAnnotationParser::parseRDFAnnotation(mAnnotation, mCVTerms, 
-                                            &(stream), getMetaId().c_str());
+    delete mHistory;
+    if (RDFAnnotationParser::hasHistoryRDFAnnotation(mAnnotation))
+    {
+      mHistory = RDFAnnotationParser::parseRDFAnnotation(mAnnotation, 
+                                            getMetaId().c_str(), &(stream));
+
+      if (mHistory != NULL && mHistory->hasRequiredAttributes() == false)
+      {
+        logError(RDFNotCompleteModelHistory, getLevel(), getVersion(),
+          "An invalid ModelHistory element has been stored.");
+      }
+      setModelHistory(mHistory);
+    }
+    else
+      mHistory = NULL;
+    if (RDFAnnotationParser::hasCVTermRDFAnnotation(mAnnotation))
+      RDFAnnotationParser::parseRDFAnnotation(mAnnotation, mCVTerms, 
+                                               getMetaId().c_str(), &(stream));
 //    new_annotation = RDFAnnotationParser::deleteRDFAnnotation(mAnnotation);
 //    delete mAnnotation;
 //    mAnnotation = new_annotation;
@@ -1942,7 +1958,7 @@ SpeciesReference_isSetConstant (const SpeciesReference_t *sr)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1975,7 +1991,7 @@ SpeciesReference_setId (SpeciesReference_t *sr, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -2008,7 +2024,7 @@ SpeciesReference_setName (SpeciesReference_t *sr, const char *name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -2040,7 +2056,7 @@ SpeciesReference_setSpecies (SpeciesReference_t *sr, const char *sid)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  */
@@ -2080,7 +2096,7 @@ SpeciesReference_createStoichiometryMath (SpeciesReference_t *sr)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_UNEXPECTED_ATTRIBUTE
@@ -2126,7 +2142,7 @@ SpeciesReference_setStoichiometryMath (  SpeciesReference_t *sr
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  */
@@ -2153,7 +2169,7 @@ SpeciesReference_setDenominator (SpeciesReference_t *sr, int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_UNEXPECTED_ATTRIBUTE
@@ -2180,7 +2196,7 @@ SpeciesReference_setConstant (SpeciesReference_t *sr, int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2201,7 +2217,7 @@ SpeciesReference_unsetId (SpeciesReference_t *sr)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2224,7 +2240,7 @@ SpeciesReference_unsetName (SpeciesReference_t *sr)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2254,7 +2270,7 @@ SpeciesReference_unsetStoichiometryMath (SpeciesReference_t *sr)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
