@@ -55,7 +55,9 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /*
  * create a new CVTerm
  */
-CVTerm::CVTerm(QualifierType_t type)
+CVTerm::CVTerm(QualifierType_t type) :
+    mHasBeenModified (false)
+
 {
   mResources = new XMLAttributes();
 
@@ -73,7 +75,8 @@ CVTerm::CVTerm(QualifierType_t type)
  * this assumes that the XMLNode has a prefix 
  * that represents a CV term
  */
-CVTerm::CVTerm(const XMLNode node)
+CVTerm::CVTerm(const XMLNode node) :
+    mHasBeenModified (false)
 {
   const string& name = node.getName();
   const string& prefix = node.getPrefix();
@@ -133,6 +136,7 @@ CVTerm::CVTerm(const CVTerm& orig)
     mModelQualifier = orig.mModelQualifier;
     mBiolQualifier  = orig.mBiolQualifier;
     mResources      = new XMLAttributes(*orig.mResources);
+    mHasBeenModified = orig.mHasBeenModified;
   }
 }
 
@@ -154,6 +158,8 @@ CVTerm::operator=(const CVTerm& rhs)
 
     delete mResources;
     mResources=new XMLAttributes(*rhs.mResources);
+
+    mHasBeenModified = rhs.mHasBeenModified;
   }
 
   return *this;
@@ -190,6 +196,7 @@ CVTerm::setQualifierType(QualifierType_t type)
     mModelQualifier = BQM_UNKNOWN;
   }
 
+  mHasBeenModified = true;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -205,6 +212,7 @@ CVTerm::setModelQualifierType(ModelQualifierType_t type)
   {
     mModelQualifier = type;
     mBiolQualifier = BQB_UNKNOWN;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -226,6 +234,7 @@ CVTerm::setBiologicalQualifierType(BiolQualifierType_t type)
   {
     mBiolQualifier = type;
     mModelQualifier = BQM_UNKNOWN;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -348,6 +357,7 @@ CVTerm::addResource(const std::string& resource)
   }
   else
   {
+    mHasBeenModified = true;
     return mResources->addResource("rdf:resource", resource);
   }
 }
@@ -364,6 +374,7 @@ CVTerm::removeResource(std::string resource)
   {
     if (resource == mResources->getValue(n))
     {
+      mHasBeenModified = true;
       result = mResources->removeResource(n);
     }
   }
@@ -420,6 +431,22 @@ CVTerm::hasRequiredAttributes()
 
   return valid;
 }
+
+bool
+CVTerm::hasBeenModified()
+{
+  return mHasBeenModified;
+}
+
+void
+CVTerm::resetModifiedFlags()
+{
+  mHasBeenModified = false;
+}
+
+
+
+
 /** @endcond */
 
 
@@ -611,7 +638,7 @@ CVTerm_getResourceURI(CVTerm_t * cv, unsigned int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -633,7 +660,7 @@ CVTerm_setQualifierType(CVTerm_t * term, QualifierType_t type)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -659,7 +686,7 @@ CVTerm_setModelQualifierType(CVTerm_t * term, ModelQualifierType_t type)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -684,7 +711,7 @@ CVTerm_setBiologicalQualifierType(CVTerm_t * term, BiolQualifierType_t type)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -713,7 +740,7 @@ CVTerm_setModelQualifierTypeByString(CVTerm_t * term, const char* qualifier)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -742,7 +769,7 @@ CVTerm_setBiologicalQualifierTypeByString(CVTerm_t * term, const char* qualifier
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -767,7 +794,7 @@ CVTerm_addResource(CVTerm_t * term, const char * resource)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
