@@ -47,7 +47,8 @@ Date::Date(unsigned int year, unsigned int month,
     unsigned int day, unsigned int hour, 
     unsigned int minute, unsigned int second,
     unsigned int sign, unsigned int hoursOffset,
-    unsigned int minutesOffset)
+    unsigned int minutesOffset) :
+  mHasBeenModified (false)
 {
   mYear   = year;
   mMonth  = month;
@@ -67,7 +68,8 @@ Date::Date(unsigned int year, unsigned int month,
 /*
  * creates a date from a string
  */
-Date::Date (const std::string& date) 
+Date::Date (const std::string& date) :
+  mHasBeenModified (false)
 { 
   if (&(date) == NULL)
     mDate = "";
@@ -103,6 +105,8 @@ Date::Date(const Date& orig)
     mMinutesOffset  = orig.mMinutesOffset;;
 
     mDate = orig.mDate;
+
+    mHasBeenModified = orig.mHasBeenModified;
   }
 }
 
@@ -129,6 +133,8 @@ Date& Date::operator=(const Date& rhs)
     mMinutesOffset  = rhs.mMinutesOffset;;
 
     mDate = rhs.mDate;
+
+    mHasBeenModified = rhs.mHasBeenModified;
   }
 
   return *this;
@@ -158,6 +164,7 @@ Date::setYear    (unsigned int year)
   {
     mYear = year;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -178,6 +185,7 @@ Date::setMonth   (unsigned int month)
   {
     mMonth = month;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -235,6 +243,7 @@ Date::setDay     (unsigned int day)
   {
     mDay = day;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 } 
@@ -245,7 +254,7 @@ Date::setDay     (unsigned int day)
 int 
 Date::setHour    (unsigned int hour)
 {
-  if (hour < 0 || hour > 23)
+  if (/*hour < 0 ||*/ hour > 23)
   {
     mHour = 0;
     parseDateNumbersToString();
@@ -255,6 +264,7 @@ Date::setHour    (unsigned int hour)
   {
     mHour = hour;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -265,7 +275,7 @@ Date::setHour    (unsigned int hour)
 int 
 Date::setMinute  (unsigned int minute)
 {
-  if (minute < 0 || minute > 59)
+  if (/*minute < 0 ||*/ minute > 59)
   {
     mMinute = 0;
     parseDateNumbersToString();
@@ -275,6 +285,7 @@ Date::setMinute  (unsigned int minute)
   {
     mMinute = minute;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -285,7 +296,7 @@ Date::setMinute  (unsigned int minute)
 int 
 Date::setSecond  (unsigned int second)
 {
-  if (second < 0 || second > 59)
+  if (/*second < 0 ||*/ second > 59)
   {
     mSecond = 0;
     parseDateNumbersToString();
@@ -295,6 +306,7 @@ Date::setSecond  (unsigned int second)
   {
     mSecond = second;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -305,7 +317,7 @@ Date::setSecond  (unsigned int second)
 int 
 Date::setSignOffset    (unsigned int sign)
 {
-  if (sign < 0 || sign > 1)
+  if (/*sign < 0 ||*/ sign > 1)
   {
     mSignOffset = 0;
     parseDateNumbersToString();
@@ -315,6 +327,7 @@ Date::setSignOffset    (unsigned int sign)
   {
     mSignOffset = sign;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -326,7 +339,7 @@ Date::setSignOffset    (unsigned int sign)
 int 
 Date::setHoursOffset    (unsigned int hour)
 {
-  if (hour < 0 || hour > 12)
+  if (/*hour < 0 ||*/ hour > 12)
   {
     mHoursOffset = 0;
     parseDateNumbersToString();
@@ -336,6 +349,7 @@ Date::setHoursOffset    (unsigned int hour)
   {
     mHoursOffset = hour;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -346,7 +360,7 @@ Date::setHoursOffset    (unsigned int hour)
 int 
 Date::setMinutesOffset  (unsigned int minute)
 {
-  if (minute < 0 || minute > 59)
+  if (/*minute < 0 ||*/ minute > 59)
   {
     mMinutesOffset = 0;
     parseDateNumbersToString();
@@ -356,6 +370,7 @@ Date::setMinutesOffset  (unsigned int minute)
   {
     mMinutesOffset = minute;
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -386,6 +401,7 @@ Date::setDateAsString (const std::string& date)
     // rewrite date string to reflect the defaults
     parseDateStringToNumbers();
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 
@@ -404,6 +420,7 @@ Date::setDateAsString (const std::string& date)
   {
     parseDateStringToNumbers();
     parseDateNumbersToString();
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -640,6 +657,21 @@ Date::representsValidDate()
   
   return valid;
 }
+
+bool
+Date::hasBeenModified()
+{
+  return mHasBeenModified;
+}
+
+void
+Date::resetModifiedFlags()
+{
+  mHasBeenModified = false;
+}
+
+
+
 /** @endcond */
 
 
@@ -889,7 +921,7 @@ Date_getMinutesOffset(Date_t * date)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -912,7 +944,7 @@ Date_setYear(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -935,7 +967,7 @@ Date_setMonth(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -958,7 +990,7 @@ Date_setDay(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -981,7 +1013,7 @@ Date_setHour(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1004,7 +1036,7 @@ Date_setMinute(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1028,7 +1060,7 @@ Date_setSecond(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1052,7 +1084,7 @@ Date_setSignOffset(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1076,7 +1108,7 @@ Date_setHoursOffset(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -1098,7 +1130,7 @@ Date_setMinutesOffset(Date_t * date, unsigned int value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
