@@ -44,7 +44,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  * Creates a new ModelCreator.
  */
 ModelCreator::ModelCreator () :
- mAdditionalRDF(NULL)
+    mAdditionalRDF(NULL)
+  , mHasBeenModified (false)
 {
 }
 
@@ -52,39 +53,55 @@ ModelCreator::ModelCreator () :
  * create a new ModelCreator from an XMLNode
  */
 ModelCreator::ModelCreator(const XMLNode creator):
-  mAdditionalRDF(NULL)
+    mAdditionalRDF(NULL)
+  , mHasBeenModified (false)
 {
   // check that this is the right place in the RDF Annotation
   if (creator.getName() == "li")
   {
-    for (unsigned int n = 0; n < creator.getNumChildren(); n++)
+    int numChildren = static_cast<int>(creator.getNumChildren());
+    int n;
+
+    // we expect an N / EMAIL / ORG in that order 
+    // find the positions of the first occurence of each
+    int Npos = -1;
+    int EMAILpos = -1;
+    int ORGpos = -1;
+    for (n = 0; n < numChildren; n++)
     {
       const string& name = creator.getChild(n).getName();
-      if (name == "N")
-      {
-        for (unsigned int p = 0; p < creator.getChild(n).getNumChildren(); p++)
-        {
-          XMLNode names = creator.getChild(n).getChild(p);
-          if (names.getName() == "Family")
-          {
-            setFamilyName(names.getChild(0).getCharacters());
-          }
-          else if (names.getName() == "Given")
-          {
-            setGivenName(names.getChild(0).getCharacters());
-          }
-        }
+      if (name == "N" && Npos < 0)
+        Npos = n;
+      else if (name == "EMAIL" && EMAILpos < 0 && n > Npos)
+        EMAILpos = n;
+      else if (name == "ORG" && ORGpos < 0 && n > EMAILpos)
+        ORGpos = n;
+    }
 
-      }
-      else if (name == "EMAIL")
-      {
-        setEmail(creator.getChild(n).getChild(0).getCharacters());
-      }
-      else if (name == "ORG")
-      {
-        setOrganization(creator.getChild(n).getChild(0).getChild(0).getCharacters());
-      }
-      else
+    //get Names
+    if (Npos >= 0)
+    {
+      setFamilyName(creator.getChild(Npos).getChild("Family").getChild(0).getCharacters());
+      setGivenName(creator.getChild(Npos).getChild("Given").getChild(0).getCharacters());
+    }
+
+    // get EMAIL
+    if (EMAILpos >= 0)
+    {
+      setEmail(creator.getChild(EMAILpos).getChild(0).getCharacters());
+    }
+
+    // get ORG
+    if (ORGpos >= 0)
+    {
+      setOrganization(creator.getChild(ORGpos).getChild("Orgname")
+                             .getChild(0).getCharacters());
+    }
+    // loop thru and save any other elements
+    numChildren = static_cast<int>(creator.getNumChildren());
+    for (n = 0; n < numChildren; n++)
+    {
+      if (n != Npos && n != EMAILpos && n!= ORGpos)
       {
         if (mAdditionalRDF == NULL)
         {
@@ -126,6 +143,9 @@ ModelCreator::ModelCreator(const ModelCreator& orig)
       this->mAdditionalRDF = orig.mAdditionalRDF->clone();
     else
       this->mAdditionalRDF = NULL;
+
+    mHasBeenModified = orig.mHasBeenModified;
+
   }
 }
 
@@ -151,6 +171,8 @@ ModelCreator& ModelCreator::operator=(const ModelCreator& rhs)
       this->mAdditionalRDF = rhs.mAdditionalRDF->clone();
     else
       this->mAdditionalRDF = NULL;
+
+    mHasBeenModified = rhs.mHasBeenModified;
   }
 
   return *this;
@@ -214,6 +236,7 @@ ModelCreator::setFamilyName(const std::string& name)
   else
   {
     mFamilyName = name;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -232,6 +255,7 @@ ModelCreator::setGivenName(const std::string& name)
   else
   {
     mGivenName = name;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -250,6 +274,7 @@ ModelCreator::setEmail(const std::string& email)
   else
   {
     mEmail = email;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -265,6 +290,7 @@ ModelCreator::setOrganization(const std::string& organization)
   else
   {
     mOrganization = organization;
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
 }
@@ -284,6 +310,7 @@ ModelCreator::unsetFamilyName()
 
   if (mFamilyName.empty()) 
   {
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -300,6 +327,7 @@ ModelCreator::unsetGivenName()
 
   if (mGivenName.empty()) 
   {
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -316,6 +344,7 @@ ModelCreator::unsetEmail()
 
   if (mEmail.empty()) 
   {
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -332,6 +361,7 @@ ModelCreator::unsetOrganization()
 
   if (mOrganization.empty()) 
   {
+    mHasBeenModified = true;
     return LIBSBML_OPERATION_SUCCESS;
   }
   else
@@ -374,6 +404,23 @@ ModelCreator::hasRequiredAttributes()
 }
 
 
+/** @cond doxygen-libsbml-internal */
+bool
+ModelCreator::hasBeenModified()
+{
+  return mHasBeenModified;
+}
+/** @endcond */
+
+
+/** @cond doxygen-libsbml-internal */
+void
+ModelCreator::resetModifiedFlags()
+{
+  mHasBeenModified = false;
+}
+/** @endcond */
+
 
 /**
  * Creates a new ModelCreator_t structure and returns a pointer to it.
@@ -612,7 +659,7 @@ ModelCreator_isSetOrganization(ModelCreator_t *mc)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -634,7 +681,7 @@ ModelCreator_setFamilyName(ModelCreator_t *mc, char * name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -656,7 +703,7 @@ ModelCreator_setGivenName(ModelCreator_t *mc, char * name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -680,7 +727,7 @@ ModelCreator_setEmail(ModelCreator_t *mc, char * email)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -702,7 +749,7 @@ ModelCreator_setOrganisation(ModelCreator_t *mc, char * org)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -722,7 +769,7 @@ ModelCreator_setOrganization(ModelCreator_t *mc, char * org)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -744,7 +791,7 @@ ModelCreator_unsetFamilyName(ModelCreator_t *mc)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -766,7 +813,7 @@ ModelCreator_unsetGivenName(ModelCreator_t *mc)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -790,7 +837,7 @@ ModelCreator_unsetEmail(ModelCreator_t *mc)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -812,7 +859,7 @@ ModelCreator_unsetOrganisation(ModelCreator_t *mc)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
