@@ -42,34 +42,34 @@
  * a single date of @em creation, and one or more @em modification dates.
  * The overall XML form of this data takes the following form:
  * 
-<div class="fragment">
-&lt;dc:creator&gt;<br>
-&nbsp;&nbsp;&lt;rdf:Bag&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&lt;rdf:li rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="background-color: #d0eed0">+++</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;vCard:N rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; &lt;vCard:Family&gt;<span style="background-color: #bbb">family name</span>&lt;/vCard:Family&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; &lt;vCard:Given&gt;<span style="background-color: #bbb">given name</span>&lt;/vCard:Given&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;/vCard:N&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="background-color: #d0eed0">+++</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="border-bottom: 2px dotted #888">&lt;vCard:EMAIL&gt;<span style="background-color: #bbb">email address</span>&lt;/vCard:EMAIL&gt;</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="background-color: #d0eed0">+++</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="border-bottom: 2px dotted #888">&lt;vCard:ORG rdf:parseType="Resource"&gt;</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="border-bottom: 2px dotted #888">&lt;vCard:Orgname&gt;<span style="background-color: #bbb">organization name</span>&lt;/vCard:Orgname&gt;</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="border-bottom: 2px dotted #888">&lt;/vCard:ORG&gt;</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span style="background-color: #d0eed0">+++</span><br>
-&nbsp;&nbsp;&nbsp;&nbsp;&lt;/rdf:li&gt;<br>
-&nbsp;&nbsp;&nbsp;&nbsp;<span style="background-color: #edd">...</span><br>
-&nbsp;&nbsp;&lt;/rdf:Bag&gt;<br>
-&lt;/dc:creator&gt;<br>
-&lt;dcterms:created rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&lt;dcterms:W3CDTF&gt;<span style="background-color: #bbb">creation date</span>&lt;/dcterms:W3CDTF&gt;<br>
-&lt;/dcterms:created&gt;<br>
-&lt;dcterms:modified rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&lt;dcterms:W3CDTF&gt;<span style="background-color: #bbb">modification date</span>&lt;/dcterms:W3CDTF&gt;<br>
-&lt;/dcterms:modified&gt;<br>
-<span style="background-color: #edd">...</span><br>
-</div>
+ <pre class="fragment">
+ &lt;dc:creator&gt;
+   &lt;rdf:Bag&gt;
+     &lt;rdf:li rdf:parseType="Resource"&gt;
+       <span style="background-color: #d0eed0">+++</span>
+       &lt;vCard:N rdf:parseType="Resource"&gt;
+         &lt;vCard:Family&gt;<span style="background-color: #bbb">family name</span>&lt;/vCard:Family&gt;
+         &lt;vCard:Given&gt;<span style="background-color: #bbb">given name</span>&lt;/vCard:Given&gt;
+       &lt;/vCard:N&gt;
+       <span style="background-color: #d0eed0">+++</span>
+       <span style="border-bottom: 2px dotted #888">&lt;vCard:EMAIL&gt;<span style="background-color: #bbb">email address</span>&lt;/vCard:EMAIL&gt;</span>
+       <span style="background-color: #d0eed0">+++</span>
+       <span style="border-bottom: 2px dotted #888">&lt;vCard:ORG rdf:parseType="Resource"&gt;</span>
+        <span style="border-bottom: 2px dotted #888">&lt;vCard:Orgname&gt;<span style="background-color: #bbb">organization name</span>&lt;/vCard:Orgname&gt;</span>
+       <span style="border-bottom: 2px dotted #888">&lt;/vCard:ORG&gt;</span>
+       <span style="background-color: #d0eed0">+++</span>
+     &lt;/rdf:li&gt;
+     <span style="background-color: #edd">...</span>
+   &lt;/rdf:Bag&gt;
+ &lt;/dc:creator&gt;
+ &lt;dcterms:created rdf:parseType="Resource"&gt;
+   &lt;dcterms:W3CDTF&gt;<span style="background-color: #bbb">creation date</span>&lt;/dcterms:W3CDTF&gt;
+ &lt;/dcterms:created&gt;
+ &lt;dcterms:modified rdf:parseType="Resource"&gt;
+   &lt;dcterms:W3CDTF&gt;<span style="background-color: #bbb">modification date</span>&lt;/dcterms:W3CDTF&gt;
+ &lt;/dcterms:modified&gt;
+ <span style="background-color: #edd">...</span>
+ </pre>
  *
  * In the template above, the <span style="border-bottom: 2px dotted #888">underlined</span>
  * portions are optional, the symbol
@@ -117,18 +117,18 @@
  * annotations in SBML.  The following template illustrates these different
  * fields when they are written in XML form:
  *
-<div class="fragment">
-&lt;vCard:N rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&lt;vCard:Family&gt;<span style="background-color: #bbb">family name</span>&lt;/vCard:Family&gt;<br>
-&nbsp;&nbsp;&lt;vCard:Given&gt;<span style="background-color: #bbb">given name</span>&lt;/vCard:Given&gt;<br>
-&lt;/vCard:N&gt;<br>
-...<br>
-&lt;vCard:EMAIL&gt;<span style="background-color: #bbb">email address</span>&lt;/vCard:EMAIL&gt;<br>
-...<br>
-&lt;vCard:ORG rdf:parseType="Resource"&gt;<br>
-&nbsp;&nbsp;&lt;vCard:Orgname&gt;<span style="background-color: #bbb">organization</span>&lt;/vCard:Orgname&gt;<br>
-&lt;/vCard:ORG&gt;<br>
-</div>
+ <pre class="fragment">
+ &lt;vCard:N rdf:parseType="Resource"&gt;
+   &lt;vCard:Family&gt;<span style="background-color: #bbb">family name</span>&lt;/vCard:Family&gt;
+   &lt;vCard:Given&gt;<span style="background-color: #bbb">given name</span>&lt;/vCard:Given&gt;
+ &lt;/vCard:N&gt;
+ ...
+ &lt;vCard:EMAIL&gt;<span style="background-color: #bbb">email address</span>&lt;/vCard:EMAIL&gt;
+ ...
+ &lt;vCard:ORG rdf:parseType="Resource"&gt;
+   &lt;vCard:Orgname&gt;<span style="background-color: #bbb">organization</span>&lt;/vCard:Orgname&gt;
+ &lt;/vCard:ORG&gt;
+ </pre>
  *
  * Each of the separate data values
  * <span class="code" style="background-color: #bbb">family name</span>,
@@ -282,7 +282,7 @@ public:
    *
    * @param orig the object to copy.
    * 
-   * @throws @if python ValueError @else SBMLConstructorException @endif
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
    * Thrown if the argument @p orig is @c NULL.
    */
   ModelHistory(const ModelHistory& orig);
@@ -294,7 +294,7 @@ public:
    * @param rhs The object whose values are used as the basis of the
    * assignment.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
    * Thrown if the argument @p rhs is @c NULL.
    */
   ModelHistory& operator=(const ModelHistory& rhs);
@@ -360,7 +360,7 @@ public:
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -376,7 +376,7 @@ public:
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
@@ -398,7 +398,7 @@ public:
    * 
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
@@ -459,7 +459,7 @@ public:
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -518,6 +518,15 @@ public:
    */ 
   bool hasRequiredAttributes();
 
+    
+  /** @cond doxygen-libsbml-internal */
+   
+  bool hasBeenModified();
+
+  void resetModifiedFlags();
+   
+  /** @endcond */
+
 
 protected:
   /** @cond doxygen-libsbml-internal */
@@ -536,6 +545,9 @@ protected:
   
   List * mModifiedDates;
 
+  bool mHasBeenModified;
+
+
   /** @endcond */
 };
 
