@@ -37,7 +37,8 @@
 #include <check.h>
 
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -403,7 +404,7 @@ create_suite_Date_newSetters (void)
 }
 
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
