@@ -36,7 +36,8 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -426,6 +427,6 @@ create_suite_ModelHistory (void)
 }
 
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
