@@ -40,7 +40,8 @@
  * separate header file is not necessary and only adds a maintenance burden
  * to keep the two files synchronized.
  */
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -56,6 +57,8 @@ Suite *create_suite_CopyAndClone (void);
 Suite *create_suite_Validation (void);
 Suite *create_suite_RDFAnnotation_C (void);
 Suite *create_suite_L3ModelHistory (void);
+Suite *create_suite_SyncAnnotation (void);
+Suite *create_suite_RDFAnnotationMetaid (void);
 
 /**
  * Global.
@@ -112,6 +115,8 @@ main (int argc, char* argv[])
   srunner_add_suite( runner, create_suite_Validation () );
   srunner_add_suite( runner, create_suite_RDFAnnotation_C () );
   srunner_add_suite( runner, create_suite_L3ModelHistory  () );
+  srunner_add_suite( runner, create_suite_SyncAnnotation  () );
+  srunner_add_suite( runner, create_suite_RDFAnnotationMetaid () );
 
   if (argc > 1 && !strcmp(argv[1], "-nofork"))
   {
@@ -126,7 +131,7 @@ main (int argc, char* argv[])
   return num_failed;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
