@@ -187,11 +187,11 @@ bool
 zipfilebuf::open_mode(std::ios_base::openmode mode,
                      char* c_mode) const
 {
-  bool testb = mode & std::ios_base::binary;
-  bool testi = mode & std::ios_base::in;
-  bool testo = mode & std::ios_base::out;
-  bool testt = mode & std::ios_base::trunc;
-  bool testa = mode & std::ios_base::app;
+  bool testb = (mode & std::ios_base::binary) == std::ios_base::binary;
+  bool testi = (mode & std::ios_base::in) == std::ios_base::in;
+  bool testo = (mode & std::ios_base::out) == std::ios_base::out;
+  bool testt = (mode & std::ios_base::trunc) == std::ios_base::trunc;
+  bool testa = (mode & std::ios_base::app) == std::ios_base::app;
 
   // Check for valid flag combinations - see [27.8.1.3.2] (Table 92)
   // Original zfstream hardcoded the compression level to maximum here...
@@ -251,7 +251,7 @@ zipfilebuf::underflow()
   // Attempt to fill internal buffer from zip file
   // (buffer must be guaranteed to exist...)
 // jouraku
-  int bytes_read = unzipread(rfile, buffer, buffer_size);
+  int bytes_read = unzipread(rfile, buffer, (unsigned int)buffer_size);
   // Indicates error or EOF
   if (bytes_read <= 0)
   {
@@ -374,7 +374,7 @@ zipfilebuf::enable_buffer()
     if (buffer_size > 0)
     {
       // Allocate internal buffer
-      buffer = new char_type[buffer_size];
+      buffer = new char_type[(unsigned int)buffer_size];
       // Get area starts empty and will be expanded by underflow as need arises
       this->setg(buffer, buffer, buffer);
       // Setup entire internal buffer as put area.
@@ -387,7 +387,7 @@ zipfilebuf::enable_buffer()
     {
       // Even in "unbuffered" case, (small?) get buffer is still required
       buffer_size = SMALLBUFSIZE;
-      buffer = new char_type[buffer_size];
+      buffer = new char_type[(unsigned int)buffer_size];
       this->setg(buffer, buffer, buffer);
       // "Unbuffered" means no put buffer
       this->setp(0, 0);
