@@ -31,7 +31,8 @@
 #include <sbml/conversion/SBMLFunctionDefinitionConverter.h>
 #include <sbml/conversion/SBMLConverterRegistry.h>
 #include <sbml/conversion/SBMLConverterRegister.h>
-#include <sbml/SBMLTypes.h>
+#include <sbml/SBMLDocument.h>
+#include <sbml/Model.h>
 
 #ifdef __cplusplus
 
@@ -45,7 +46,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /** @cond doxygen-libsbml-internal */
 void SBMLFunctionDefinitionConverter::init()
 {
-  SBMLConverterRegistry::getInstance().addConverter(new SBMLFunctionDefinitionConverter());
+  SBMLFunctionDefinitionConverter converter;
+  SBMLConverterRegistry::getInstance().addConverter(&converter);
 }
 /** @endcond */
 
