@@ -30,7 +30,8 @@
 #include <sbml/conversion/SBMLInitialAssignmentConverter.h>
 #include <sbml/conversion/SBMLConverterRegistry.h>
 #include <sbml/conversion/SBMLConverterRegister.h>
-#include <sbml/SBMLTypes.h>
+#include <sbml/SBMLDocument.h>
+#include <sbml/Model.h>
 
 #ifdef __cplusplus
 
@@ -44,7 +45,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /** @cond doxygen-libsbml-internal */
 void SBMLInitialAssignmentConverter::init()
 {
-  SBMLConverterRegistry::getInstance().addConverter(new SBMLInitialAssignmentConverter());
+  SBMLInitialAssignmentConverter converter;
+  SBMLConverterRegistry::getInstance().addConverter(&converter);
 }
 /** @endcond */
 
