@@ -31,8 +31,13 @@
 #include <sbml/conversion/SBMLRuleConverter.h>
 #include <sbml/conversion/SBMLConverterRegistry.h>
 #include <sbml/conversion/SBMLConverterRegister.h>
-
-#include <sbml/SBMLTypes.h>
+#include <sbml/math/ASTNode.h>
+#include <sbml/AlgebraicRule.h>
+#include <sbml/AssignmentRule.h>
+#include <sbml/RateRule.h>
+#include <sbml/InitialAssignment.h>
+#include <sbml/SBMLDocument.h>
+#include <sbml/Model.h>
 
 #ifdef __cplusplus
 
@@ -48,7 +53,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /** @cond doxygen-libsbml-internal */
 void SBMLRuleConverter::init()
 {
-  SBMLConverterRegistry::getInstance().addConverter(new SBMLRuleConverter());
+  SBMLRuleConverter converter;
+  SBMLConverterRegistry::getInstance().addConverter(&converter);
 }
 /** @endcond */
 
