@@ -31,7 +31,8 @@
 #include <sbml/conversion/SBMLConverterRegister.h>
 #include <sbml/extension/SBasePlugin.h>
 
-#include <sbml/SBMLTypes.h>
+#include <sbml/Model.h>
+#include <sbml/AlgebraicRule.h>
 
 #ifdef __cplusplus
 
@@ -45,7 +46,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 /** @cond doxygen-libsbml-internal */
 void SBMLUnitsConverter::init()
 {
-  SBMLConverterRegistry::getInstance().addConverter(new SBMLUnitsConverter());
+  SBMLUnitsConverter converter;
+  SBMLConverterRegistry::getInstance().addConverter(&converter);
 }
 /** @endcond */
 
