@@ -40,7 +40,8 @@
  * separate header file is not necessary and only adds a maintenance burden
  * to keep the two files synchronized.
  */
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -114,7 +115,7 @@ main (void)
   return num_failed;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
