@@ -45,7 +45,8 @@ SBMLDocumentPlugin::SBMLDocumentPlugin (const std::string &uri,
                                         const std::string &prefix,
                                         SBMLNamespaces *sbmlns)
   : SBasePlugin(uri,prefix,sbmlns)
-  , mRequired(false)
+  , mRequired(true)
+  , mIsSetRequired(false)
 {
 }
 
@@ -56,6 +57,7 @@ SBMLDocumentPlugin::SBMLDocumentPlugin (const std::string &uri,
 SBMLDocumentPlugin::SBMLDocumentPlugin(const SBMLDocumentPlugin& orig)
   : SBasePlugin(orig)
   , mRequired(orig.mRequired)
+  , mIsSetRequired(orig.mIsSetRequired)
 {
 }
 
@@ -75,6 +77,7 @@ SBMLDocumentPlugin::operator=(const SBMLDocumentPlugin& orig)
   {
     this->SBasePlugin::operator =(orig);
     mRequired = orig.mRequired;
+    mIsSetRequired = orig.mIsSetRequired;
   }    
 
   return *this;
@@ -134,9 +137,26 @@ SBMLDocumentPlugin::readAttributes (const XMLAttributes& attributes,
   SBasePlugin::readAttributes(attributes, expectedAttributes);
 
   if ( mSBMLExt->getLevel(mURI) > 2)
-  {    
-    XMLTriple tripleRequired("required", mURI, mPrefix);
-    attributes.readInto(tripleRequired, mRequired, getErrorLog(), true, getLine(), getColumn());
+  {  
+    // check level of document version smaller than plugin
+    // and report invalid if it is
+    if (this->getSBMLDocument() != NULL &&
+        this->getSBMLDocument()->getLevel() < mSBMLExt->getLevel(mURI))
+    {
+      // we should not have a package ns in an l2 document
+      this->getSBMLDocument()->getErrorLog()->logError(L3PackageOnLowerSBML, 
+                                      this->getSBMLDocument()->getLevel(), 
+                                      this->getSBMLDocument()->getVersion());
+    }
+    else
+    {
+      XMLTriple tripleRequired("required", mURI, mPrefix);
+      if (attributes.readInto(tripleRequired, mRequired, getErrorLog(), 
+                              true, getLine(), getColumn())) 
+      {
+        mIsSetRequired = true;
+      }
+    }
   }
 }
 
@@ -155,10 +175,10 @@ SBMLDocumentPlugin::writeAttributes (XMLOutputStream& stream) const
     return;
 
   //cout << "[DEBUG] SBMLDocumentPlugin::writeAttributes() " << endl;
-
-  XMLTriple tripleRequired("required", mURI, mPrefix);
-
-  stream.writeAttribute(tripleRequired, mRequired);
+  if (isSetRequired()) {
+    XMLTriple tripleRequired("required", mURI, mPrefix);
+    stream.writeAttribute(tripleRequired, mRequired);
+  }
 }
 
 /** @endcond doxygen-libsbml-internal */
@@ -173,23 +193,41 @@ SBMLDocumentPlugin::writeAttributes (XMLOutputStream& stream) const
 bool 
 SBMLDocumentPlugin::getRequired() const
 {
-  return mRequired;  
+  return mRequired;
 }
 
 
+bool 
+SBMLDocumentPlugin::isSetRequired() const
+{
+  return mIsSetRequired;
+}
+
 int 
 SBMLDocumentPlugin::setRequired(bool required)
 {
   //
   // required attribute is not defined for SBML Level 2 .
   //
-  if ( mSBMLExt->getLevel(mURI) < 3)
+  if ( mSBMLExt->getLevel(mURI) < 3) {
     return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
 
   mRequired = required;
+  mIsSetRequired = true;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
+
+int 
+SBMLDocumentPlugin::unsetRequired()
+{
+  mRequired = false;
+  mIsSetRequired = false;
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
+
 /**
  * Creates a new SBMLDocumentPlugin_t structure with the given package
  * uri, prefix and SBMLNamespaces. 
@@ -238,7 +276,7 @@ SBMLDocumentPlugin_clone(SBMLDocumentPlugin_t* plugin)
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -263,7 +301,7 @@ SBMLDocumentPlugin_addExpectedAttributes(SBMLDocumentPlugin_t* plugin,
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -289,7 +327,7 @@ SBMLDocumentPlugin_readAttributes(SBMLDocumentPlugin_t* plugin,
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -346,6 +384,24 @@ SBMLDocumentPlugin_setRequired(SBMLDocumentPlugin_t* plugin, int required)
 }
 
 
+LIBSBML_EXTERN
+int
+SBMLDocumentPlugin_isSetRequired(SBMLDocumentPlugin_t* plugin)
+{
+  if (plugin == NULL) return LIBSBML_INVALID_OBJECT;
+  return plugin->isSetRequired();
+}
+
+
+LIBSBML_EXTERN
+int
+SBMLDocumentPlugin_unsetRequired(SBMLDocumentPlugin_t* plugin)
+{
+  if (plugin == NULL) return LIBSBML_INVALID_OBJECT;
+  return plugin->unsetRequired();
+}
+
+
 LIBSBML_CPP_NAMESPACE_END
 
 #endif  /* __cplusplus */
