@@ -272,19 +272,41 @@ SBasePlugin::getVersion() const
 }
 
 
+/** @cond doxygen-libsbml-internal */
 unsigned int 
 SBasePlugin::getLine() const
 {
   if (mParent == NULL) return 0;
   return mParent->getLine();
 }
+/** @endcond */
 
+
+/** @cond doxygen-libsbml-internal */
 unsigned int 
 SBasePlugin::getColumn() const
 {
   if (mParent == NULL) return 0;
   return mParent->getColumn();
 }
+/** @endcond */
+
+
+/** @cond doxygen-libsbml-internal */
+SBMLNamespaces *
+SBasePlugin::getSBMLNamespaces() const
+{
+  if (mSBML != NULL)
+    return mSBML->getSBMLNamespaces();
+  else if (mParent != NULL)
+    return mParent->getSBMLNamespaces();
+  else if (mSBMLNS != NULL)
+    return mSBMLNS;
+  else
+    return new SBMLNamespaces();
+}
+/** @endcond */
+
 
 /*
  * Returns the package version of this plugin object.
@@ -299,25 +321,26 @@ SBasePlugin::getPackageVersion() const
 
 
 /** @cond doxygen-libsbml-internal */
-/*
- * This function does nothing itself--subclasses with ASTNode subelements must override this function.
- */
 void 
 SBasePlugin::replaceSIDWithFunction(const std::string& id, const ASTNode* function)
 {
 }
-/** @endcond doxygen-libsbml-internal */
+/** @endcond */
 
 
 /** @cond doxygen-libsbml-internal */
-/*
- * This function does nothing itself--subclasses with ASTNode subelements must override this function.
- */
 void 
 SBasePlugin::divideAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function)
 {
 }
-/** @endcond doxygen-libsbml-internal */
+/** @endcond */
+
+/** @cond doxygen-libsbml-internal */
+void 
+SBasePlugin::multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function)
+{
+}
+/** @endcond */
 
 /** @cond doxygen-libsbml-internal */
 bool SBasePlugin::hasIdentifierBeginningWith(const std::string& prefix)
@@ -347,6 +370,9 @@ SBasePlugin::getElementNamespace() const
 std::string 
 SBasePlugin::getURI() const
 {
+  if (mSBMLExt == NULL) 
+    return getElementNamespace();
+  
   const std::string &package = mSBMLExt->getName();
   const SBMLDocument* doc = getSBMLDocument();
 
@@ -511,7 +537,7 @@ SBasePlugin::readAttributes (const XMLAttributes& attributes,
   const unsigned int sbmlVersion = getVersion();
   const unsigned int pkgVersion  = getPackageVersion();
 
-   std::string element = (mParent) ? mParent->getElementName() : "";
+   std::string element = (mParent) ? mParent->getElementName() : std::string();
 
   //
   // (NOTE)
@@ -772,7 +798,7 @@ SBasePlugin_clone(SBasePlugin_t* plugin)
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -837,7 +863,7 @@ SBasePlugin_readOtherXML(SBasePlugin_t* plugin, SBase_t* parentObject, XMLInputS
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -882,7 +908,7 @@ SBasePlugin_hasRequiredElements(SBasePlugin_t* plugin)
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -906,7 +932,7 @@ SBasePlugin_addExpectedAttributes(SBasePlugin_t* plugin, ExpectedAttributes_t* a
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -931,7 +957,7 @@ SBasePlugin_readAttributes(SBasePlugin_t* plugin, XMLAttributes_t* attributes,
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -978,7 +1004,7 @@ SBasePlugin_hasRequiredAttributes(SBasePlugin_t* plugin)
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -1006,7 +1032,7 @@ SBasePlugin_writeXMLNS(SBasePlugin_t* plugin, XMLOutputStream_t* stream)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -1039,7 +1065,7 @@ SBasePlugin_setSBMLDocument(SBasePlugin_t* plugin, SBMLDocument_t* d)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
@@ -1073,7 +1099,7 @@ SBasePlugin_connectToParent(SBasePlugin_t* plugin, SBase_t* sbase)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
