@@ -153,8 +153,6 @@
  *in their packages, otherwise package developers must implement a new SBMLDocumentPlugin derived class.)
  *</p>
  *
- *  </li>
- *
  *  <li> <p>LayoutModelPlugin class for Model element</p>
  *    <ul>
  *       <li> &lt;listOfLayouts&gt; element is added to Model object.
@@ -235,8 +233,8 @@
  *        </ul>
  *      </ul>
  *    </li>
- * </ol>
  *
+ * </ol>
  */
 
 #ifndef SBasePlugin_h
@@ -605,7 +603,7 @@ public:
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif The possible values
+   * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
    * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
    * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
@@ -661,6 +659,13 @@ public:
   virtual void divideAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function);
   /** @endcond */
 
+  /** @cond doxygen-libsbml-internal */
+  /**
+   * If this assignment assigns a value to the 'id' element, replace the 'math' object with the function (existing*function). 
+   */
+  virtual void multiplyAssignmentsToSIdByFunction(const std::string& id, const ASTNode* function);
+  /** @endcond */
+
   /** @cond doxygen-libsbml-internal */
   /**
    * Check to see if the given prefix is used by any of the IDs defined by extension elements.  A package that defines its own 'id' attribute for a core element would check that attribute here.
@@ -729,6 +734,12 @@ public:
   unsigned int getColumn() const;
   /** @endcond */
 
+  /** @cond doxygen-libsbml-internal */
+  /* gets the SBMLnamespaces - internal use only*/
+  virtual SBMLNamespaces * getSBMLNamespaces() const;
+  /** @endcond */
+
+
 protected:
   /** @cond doxygen-libsbml-internal */
   /**
