@@ -25,7 +25,7 @@
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ---------------------------------------------------------------------- -->*/
 
-#if __cplusplus
+#if defined(__cplusplus)
 #include <iostream>
 #endif
 
@@ -74,9 +74,11 @@ START_TEST (test_SBMLDocumentPlugin_create)
 	SBMLDocumentPlugin *plugin = sbmldocPluginCreator.createPlugin(uri, prefix, ns.getNamespaces());
 
 	fail_unless(plugin != NULL);
-	fail_unless(plugin->getRequired() == false);
-	plugin->setRequired(true);
+  fail_unless(plugin->isSetRequired() == false);
 	fail_unless(plugin->getRequired() == true);
+	plugin->setRequired(false);
+  fail_unless(plugin->isSetRequired() == true);
+	fail_unless(plugin->getRequired() == false);
 
 	delete plugin;
 
@@ -107,9 +109,16 @@ START_TEST (test_SBMLDocumentPlugin_c_api)
 
   SBMLDocumentPlugin_t* plugin = SBMLDocumentPlugin_create(uri.c_str(), prefix.c_str(), &ns);
 	fail_unless(plugin != NULL);
-  fail_unless(SBMLDocumentPlugin_getRequired(plugin) == (int)false);
-  SBMLDocumentPlugin_setRequired(plugin, (int)true); 
+  fail_unless(SBMLDocumentPlugin_isSetRequired(plugin) == (int)false);
   fail_unless(SBMLDocumentPlugin_getRequired(plugin) == (int)true);
+  SBMLDocumentPlugin_setRequired(plugin, (int)true); 
+  fail_unless(SBMLDocumentPlugin_isSetRequired(plugin) == (int)true);
+  fail_unless(SBMLDocumentPlugin_getRequired(plugin) == (int)true);
+  SBMLDocumentPlugin_setRequired(plugin, (int)false); 
+  fail_unless(SBMLDocumentPlugin_isSetRequired(plugin) == (int)true);
+  fail_unless(SBMLDocumentPlugin_getRequired(plugin) == (int)false);
+  SBMLDocumentPlugin_unsetRequired(plugin);
+  fail_unless(SBMLDocumentPlugin_isSetRequired(plugin) == (int)false);
 
   fail_unless(SBMLDocumentPlugin_create(NULL, NULL, NULL) == NULL);
   fail_unless(SBMLDocumentPlugin_getRequired(NULL) == LIBSBML_INVALID_OBJECT);
