@@ -25,7 +25,7 @@
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ---------------------------------------------------------------------- -->*/
 
-#if __cplusplus
+#if defined(__cplusplus)
 #include <iostream>
 #endif
 
@@ -66,7 +66,7 @@ START_TEST (test_SBasePluginCreator_create)
 	
 
 	// create a separate TestModelPlugin
-	TestExtension* ext = (TestExtension*)SBMLExtensionRegistry::getInstance().getExtension(uri);
+	// TestExtension* ext = (TestExtension*)SBMLExtensionRegistry::getInstance().getExtension(uri);
 	TestModelPlugin plugin(uri, prefix, &ns);
 
 	// assert that they are the same
