@@ -166,6 +166,16 @@ static const char *AST_RELATIONAL_STRINGS[] =
 };
 
 
+static const char *AST_OPERATOR_STRINGS[] =
+{
+    "divide"
+  , "minus"
+  , "plus"
+  , "times"
+  , "power"
+};
+
+
 /*
  * Creates a new ASTNode.
  *
@@ -693,7 +703,7 @@ ASTNode::canonicalizeRelational ()
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -721,7 +731,7 @@ ASTNode::addChild (ASTNode* child)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -1060,6 +1070,27 @@ ASTNode::getName () const
 }
 
 
+LIBSBML_EXTERN
+const char*
+ASTNode::getOperatorName () const
+{
+  switch(mType) {
+  case AST_DIVIDE:
+    return AST_OPERATOR_STRINGS[0];
+  case AST_MINUS:
+    return AST_OPERATOR_STRINGS[1];
+  case AST_PLUS:
+    return AST_OPERATOR_STRINGS[2];
+  case AST_TIMES:
+    return AST_OPERATOR_STRINGS[3];
+  case AST_POWER:
+    return AST_OPERATOR_STRINGS[4];
+  default:
+    return NULL;
+  }
+}
+
+
 /*
  * @return the value of the numerator of this ASTNode.  This function
  * should be called only when getType() == AST_RATIONAL.
@@ -1684,7 +1715,7 @@ LIBSBML_EXTERN
 int
 ASTNode::setName (const char *name)
 {
-  if (mName == name) 
+  if (getName() == name) 
     return LIBSBML_OPERATION_SUCCESS;
 
 
@@ -1945,7 +1976,7 @@ ASTNode::replaceIDWithFunction(const std::string& id, const ASTNode* function)
   for (unsigned int i=0; i<getNumChildren(); i++) {
     ASTNode* child = getChild(i);
     if (child->getType() == AST_NAME &&
-        child->getId() == id) {
+        child->getName() == id) {
       replaceChild(i, function->deepCopy());
     }
     else {
@@ -2443,7 +2474,7 @@ ASTNode_free (ASTNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_UNEXPECTED_ATTRIBUTE
@@ -2500,7 +2531,7 @@ ASTNode_canonicalize (ASTNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2522,7 +2553,7 @@ ASTNode_addChild (ASTNode_t *node, ASTNode_t *child)
  * 
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -3252,7 +3283,7 @@ ASTNode_hasUnits (const ASTNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3276,7 +3307,7 @@ ASTNode_setCharacter (ASTNode_t *node, char value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3296,7 +3327,7 @@ ASTNode_setName (ASTNode_t *node, const char *name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3316,7 +3347,7 @@ ASTNode_setInteger (ASTNode_t *node, long value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3340,7 +3371,7 @@ ASTNode_setRational (ASTNode_t *node, long numerator, long denominator)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3360,7 +3391,7 @@ ASTNode_setReal (ASTNode_t *node, double value)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3379,7 +3410,7 @@ ASTNode_setRealWithExponent (ASTNode_t *node, double mantissa, long exponent)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
@@ -3456,7 +3487,7 @@ ASTNode_setStyle (ASTNode_t *node, const char *style)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_UNEXPECTED_ATTRIBUTE
@@ -3479,7 +3510,7 @@ ASTNode_setUnits (ASTNode_t *node, const char *units)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -3544,7 +3575,7 @@ ASTNode_unsetStyle (ASTNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_UNEXPECTED_ATTRIBUTE
@@ -3617,7 +3648,7 @@ ASTNode_getParentSBMLObject(ASTNode_t* node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -3644,7 +3675,7 @@ ASTNode_removeChild(ASTNode_t* node, unsigned int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -3670,7 +3701,7 @@ ASTNode_replaceChild(ASTNode_t* node, unsigned int n, ASTNode_t * newChild)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -3695,7 +3726,7 @@ ASTNode_insertChild(ASTNode_t* node, unsigned int n, ASTNode_t * newChild)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -3751,7 +3782,7 @@ ASTNode_getSemanticsAnnotation(ASTNode_t* node, unsigned int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t.  @endif The possible values
+ * enumeration #OperationReturnValues_t.  @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
