@@ -78,22 +78,25 @@
  *
  * @if clike <h3><a class="anchor" name="ASTNodeType_t">
  * ASTNodeType_t</a></h3> @else <h3><a class="anchor"
- * name="ASTNodeType_t">The set of possible %ASTNode types</a></h3> @endif
+ * name="ASTNodeType_t">The set of possible %ASTNode types</a></h3> @endif@~
  *
- * @if clike Every ASTNode has an associated type code to indicate,
+ * Every ASTNode has an associated type code to indicate,
  * for example, whether it holds a number or stands for an arithmetic
- * operator.  The type is recorded as a value drawn from the enumeration 
- * @link ASTNode.h::ASTNodeType_t ASTNodeType_t@endlink.  The list of
- * possible types is quite long, because it covers all the mathematical
- * functions that are permitted in SBML.  The values are shown in the
- * following table: @else Every ASTNode has an associated
- * type code to indicate, for example, whether it holds a number or stands for
- * an arithmetic operator.  The type is recorded as a value drawn from a
+ * operator.
+ * @if clike The type is recorded as a value drawn from the enumeration 
+ * @link ASTNode.h::ASTNodeType_t ASTNodeType_t@endlink.@endif
+ * @if java The type is recorded as a value drawn from a
  * set of static integer constants defined in the class {@link
- * libsbmlConstants}.  Their names begin with the characters @c AST_.  The
- * list of possible types is quite long, because it covers all the
- * mathematical functions that are permitted in SBML.  The values are shown
- * in the following table: @endif
+ * libsbmlConstants}. Their names begin with the characters @c AST_.@endif
+ * @if python The type is recorded as a value drawn from a
+ * set of static integer constants defined in the class {@link
+ * libsbml}. Their names begin with the characters @c AST_.@endif
+ * @if csharp The type is recorded as a value drawn from a
+ * set of static integer constants defined in the class {@link
+ * libsbml}. Their names begin with the characters @c AST_.@endif
+ * The list of possible types is quite long, because it covers all the
+ * mathematical functions that are permitted in SBML. The values are shown
+ * in the following table:
  *
  * @htmlinclude astnode-types.html
  *
@@ -139,11 +142,13 @@
  * 
  * <h3><a class="anchor" name="math-convert">Converting between ASTs and text strings</a></h3>
  * 
- * The text-string form of mathematical formulas produced by @if clike SBML_formulaToString()@endif@if csharp SBML_formulaToString()@else <code><a href="libsbml.html#formulaToString(org.sbml.libsbml.ASTNode)">libsbml.formulaToString()</a></code>@endif and
- * read by @if clike SBML_parseFormula()@endif@if csharp SBML_parseFormula()@else <code><a href="libsbml.html#parseFormula(java.lang.String)">libsbml.parseFormula()</a></code>@endif
- * are simple C-inspired infix notation taken from SBML Level&nbsp;1.  A
+ * The text-string form of mathematical formulas produced by @if clike SBML_formulaToString()@endif@if csharp SBML_formulaToString()@endif@if python libsbml.formulaToString()@endif@if java <code><a href="libsbml.html#formulaToString(org.sbml.libsbml.ASTNode)">libsbml.formulaToString()</a></code>@endif@~ and
+ * read by @if clike SBML_parseFormula()@endif@if csharp SBML_parseFormula()@endif@if python libsbml.parseFormula()@endif@if java <code><a href="libsbml.html#parseFormula(java.lang.String)">libsbml.parseFormula(String formula)</a></code>@endif@~
+ * and
+ * @if clike SBML_parseL3Formula()@endif@if csharp SBML_parseL3Formula()@endif@if python libsbml.parseL3Formula()@endif@if java <code><a href="libsbml.html#parseL3Formula(java.lang.String)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
+ * are in a simple C-inspired infix notation.  A
  * formula in this text-string form can be handed to a program that
- * understands SBML Level&nbsp;1 mathematical expressions, or used as part
+ * understands SBML mathematical expressions, or used as part
  * of a translation system.  The libSBML distribution comes with an example
  * program in the @c "examples" subdirectory called @c translateMath that
  * implements an interactive command-line demonstration of translating
@@ -200,6 +205,15 @@
  * @htmlinclude math-functions.html
  * 
  * @warning @htmlinclude L1-math-syntax-warning.html
+ *
+ * @if clike @see SBML_parseL3Formula()@endif@~
+ * @if csharp @see SBML_parseL3Formula()@endif@~
+ * @if python @see libsbml.parseL3Formula()@endif@~
+ * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
+ * @if clike @see SBML_parseFormula()@endif@~
+ * @if csharp @see SBML_parseFormula()@endif@~
+ * @if python @see libsbml.parseFormula()@endif@~
+ * @if java @see <code><a href="libsbml.html#parseFormula(String formula)">libsbml.parseFormula(String formula)</a></code>@endif@~
  */
 
 #ifndef ASTNode_h
@@ -386,10 +400,10 @@ public:
    * @if clike setType()@else ASTNode::setType(int)@endif.
    *
    * @param type an optional
-   * @if clike @link #ASTNodeType_t ASTNodeType_t@endlink@else type@endif
+   * @if clike @link #ASTNodeType_t ASTNodeType_t@endlink@else type@endif@~
    * code indicating the type of node to create.
    *
-   * @if notcpp @docnote @htmlinclude warn-default-args-in-docs.html @endif
+   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   LIBSBML_EXTERN
   ASTNode (ASTNodeType_t type = AST_UNKNOWN);
@@ -500,7 +514,7 @@ public:
    * render the representation invalid.  Callers need to be careful to use
    * this method in the context of other operations to create complete and
    * correct formulas.  The method
-   * @if clike isWellFormedASTNode()@else ASTNode::isWellFormedASTNode()@endif
+   * @if clike isWellFormedASTNode()@else ASTNode::isWellFormedASTNode()@endif@~
    * may also be useful for checking the results of node modifications.
    *
    * @see prependChild(ASTNode* child)
@@ -628,7 +642,7 @@ public:
    * 
    * @return the nth child of this ASTNode or @c NULL if this node has no nth
    * child (<code>n &gt; </code>
-   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif
+   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif@~
    * <code>- 1</code>).
    */
   LIBSBML_EXTERN
@@ -639,7 +653,7 @@ public:
    * Get the left child of this node.
    * 
    * @return the left child of this ASTNode.  This is equivalent to calling
-   * @if clike getChild()@else ASTNode::getChild(unsigned int)@endif
+   * @if clike getChild()@else ASTNode::getChild(unsigned int)@endif@~
    * with an argument of @c 0.
    */
   LIBSBML_EXTERN
@@ -651,7 +665,7 @@ public:
    *
    * @return the right child of this ASTNode, or @c NULL if this node has no
    * right child.  If
-   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif
+   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif@~
    * <code>&gt; 1</code>, then this is equivalent to:
    * @code
    * getChild( getNumChildren() - 1 );
@@ -718,7 +732,7 @@ public:
    * 
    * @return the nth annotation of this ASTNode, or @c NULL if this node has
    * no nth annotation (<code>n &gt;</code>
-   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif
+   * @if clike getNumChildren()@else ASTNode::getNumChildren()@endif@~
    * <code>- 1</code>).
    *
    * @see ASTNode::addSemanticsAnnotation(XMLNode* sAnnotation)
@@ -733,14 +747,14 @@ public:
    * <code>predicate(node)</code> returns @c true (non-zero).
    *
    * For portability between different programming languages, the predicate
-   * is passed in as a pointer to a function.  The function definition must
-   * have the type @link ASTNode.h::ASTNodePredicate ASTNodePredicate
-   * @endlink, which is defined as
+   * is passed in as a pointer to a function.  @if clike The function
+   * definition must have the type @link ASTNode::ASTNodePredicate
+   * ASTNodePredicate @endlink, which is defined as
    * @code
    * int (*ASTNodePredicate) (const ASTNode_t *node);
    * @endcode
    * where a return value of non-zero represents @c true and zero
-   * represents @c false.
+   * represents @c false. @endif
    *
    * @param predicate the predicate to use
    *
@@ -786,7 +800,7 @@ public:
   /**
    * Get the value of this node as a single character.  This function
    * should be called only when
-   * @if clike getType()@else ASTNode::getType()@endif returns
+   * @if clike getType()@else ASTNode::getType()@endif@~ returns
    * @link ASTNodeType_t#AST_PLUS AST_PLUS@endlink,
    * @link ASTNodeType_t#AST_MINUS AST_MINUS@endlink,
    * @link ASTNodeType_t#AST_TIMES AST_TIMES@endlink,
@@ -798,6 +812,7 @@ public:
   LIBSBML_EXTERN
   char getCharacter () const;
 
+
   /**
    * Get the id of this ASTNode.  
    * 
@@ -806,6 +821,7 @@ public:
   LIBSBML_EXTERN
   std::string getId () const;
 
+
   /**
    * Get the class of this ASTNode.  
    * 
@@ -814,6 +830,7 @@ public:
   LIBSBML_EXTERN
   std::string getClass () const;
 
+
   /**
    * Get the style of this ASTNode.  
    * 
@@ -822,10 +839,11 @@ public:
   LIBSBML_EXTERN
   std::string getStyle () const;
 
+
   /**
    * Get the value of this node as an integer. This function should be
    * called only when
-   * @if clike getType()@else ASTNode::getType()@endif
+   * @if clike getType()@else ASTNode::getType()@endif@~
    * <code>== @link ASTNodeType_t#AST_INTEGER AST_INTEGER@endlink</code>.
    * 
    * @return the value of this ASTNode as a (<code>long</code>) integer. 
@@ -837,9 +855,9 @@ public:
   /**
    * Get the value of this node as a string.  This function may be called
    * on nodes that (1) are not operators, i.e., nodes for which
-   * @if clike isOperator()@else ASTNode::isOperator()@endif
+   * @if clike isOperator()@else ASTNode::isOperator()@endif@~
    * returns @c false, and (2) are not numbers, i.e.,
-   * @if clike isNumber()@else ASTNode::isNumber()@endif returns @c false.
+   * @if clike isNumber()@else ASTNode::isNumber()@endif@~ returns @c false.
    * 
    * @return the value of this ASTNode as a string.
    */
@@ -847,10 +865,22 @@ public:
   const char* getName () const;
 
 
+  /**
+   * Get the value of this operator node as a string.  This function may be called
+   * on nodes that are operators, i.e., nodes for which
+   * @if clike isOperator()@else ASTNode::isOperator()@endif@~
+   * returns @c true.
+   * 
+   * @return the name of this operator ASTNode as a string (or NULL if not an operator).
+   */
+  LIBSBML_EXTERN
+  const char* getOperatorName () const;
+
+
   /**
    * Get the value of the numerator of this node.  This function should be
    * called only when
-   * @if clike getType()@else ASTNode::getType()@endif
+   * @if clike getType()@else ASTNode::getType()@endif@~
    * <code>== @link ASTNodeType_t#AST_RATIONAL AST_RATIONAL@endlink</code>.
    * 
    * @return the value of the numerator of this ASTNode.  
@@ -862,7 +892,7 @@ public:
   /**
    * Get the value of the denominator of this node.  This function should
    * be called only when
-   * @if clike getType()@else ASTNode::getType()@endif
+   * @if clike getType()@else ASTNode::getType()@endif@~
    * <code>== @link ASTNodeType_t#AST_RATIONAL AST_RATIONAL@endlink</code>.
    * 
    * @return the value of the denominator of this ASTNode.
@@ -874,7 +904,7 @@ public:
   /**
    * Get the real-numbered value of this node.  This function
    * should be called only when
-   * @if clike isReal()@else ASTNode::isReal()@endif
+   * @if clike isReal()@else ASTNode::isReal()@endif@~
    * <code>== true</code>.
    *
    * This function performs the necessary arithmetic if the node type is
@@ -890,10 +920,10 @@ public:
 
   /**
    * Get the mantissa value of this node.  This function should be called
-   * only when @if clike getType()@else ASTNode::getType()@endif
+   * only when @if clike getType()@else ASTNode::getType()@endif@~
    * returns @link ASTNodeType_t#AST_REAL_E AST_REAL_E@endlink
    * or @link ASTNodeType_t#AST_REAL AST_REAL@endlink.
-   * If @if clike getType()@else ASTNode::getType()@endif
+   * If @if clike getType()@else ASTNode::getType()@endif@~
    * returns @link ASTNodeType_t#AST_REAL AST_REAL@endlink,
    * this method is identical to
    * @if clike getReal()@else ASTNode::getReal()@endif.
@@ -907,7 +937,7 @@ public:
   /**
    * Get the exponent value of this ASTNode.  This function should be
    * called only when
-   * @if clike getType()@else ASTNode::getType()@endif
+   * @if clike getType()@else ASTNode::getType()@endif@~
    * returns @link ASTNodeType_t#AST_REAL_E AST_REAL_E@endlink
    * or @link ASTNodeType_t#AST_REAL AST_REAL@endlink.
    * 
@@ -951,6 +981,10 @@ public:
    * @note The <code>sbml:units</code> attribute is only available in SBML
    * Level&nbsp;3.  It may not be used in Levels 1&ndash;2 of SBML.
    * 
+   * @if clike @see SBML_parseL3Formula()@endif@~
+   * @if csharp @see SBML_parseL3Formula()@endif@~
+   * @if python @see libsbml.parseL3Formula()@endif@~
+   * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
    */
   LIBSBML_EXTERN
   std::string getUnits () const;
@@ -961,6 +995,11 @@ public:
    * symbol @c avogadro.  The predicate returns @c false (zero) otherwise.
    * 
    * @return @c true if this ASTNode is the special symbol avogadro.
+   *
+   * @if clike @see SBML_parseL3Formula()@endif@~
+   * @if csharp @see SBML_parseL3Formula()@endif@~
+   * @if python @see libsbml.parseL3Formula()@endif@~
+   * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
    */
   LIBSBML_EXTERN
   bool isAvogadro () const;
@@ -1064,6 +1103,11 @@ public:
    * 
    * @return @c true if the given ASTNode represents a log10() function, @c
    * false otherwise.
+   *
+   * @if clike @see SBML_parseL3Formula()@endif@~
+   * @if csharp @see SBML_parseL3Formula()@endif@~
+   * @if python @see libsbml.parseL3Formula()@endif@~
+   * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
    */
   LIBSBML_EXTERN
   bool isLog10 () const;
@@ -1208,16 +1252,25 @@ public:
    * 
    * For numbers, unary minus nodes can be "collapsed" by negating the
    * number.  In fact, 
-   * @if clike SBML_parseFormula() @endif@if csharp SBML_parseFormula() @else <code><a href="libsbml.html#parseFormula(java.lang.String)">libsbml.parseFormula()</a></code>@endif does this during its parsing process.
-   * However, unary minus nodes for symbols
+   * @if clike SBML_parseFormula()@endif@if csharp SBML_parseFormula()@endif@if python libsbml.parseFormula()@endif@if java <code><a href="libsbml.html#parseFormula(java.lang.String)">libsbml.parseFormula(String formula)</a></code>@endif@~
+   * does this during its parsing process, and 
+   * @if clike SBML_parseL3Formula()@endif@if csharp SBML_parseL3Formula()@endif@if python libsbml.parseL3Formula()@endif@if java <code><a href="libsbml.html#parseL3Formula(java.lang.String)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
+   * has a configuration option that allows this behavior to be turned
+   * on or off.  However, unary minus nodes for symbols
    * (@link ASTNodeType_t#AST_NAME AST_NAME@endlink) cannot
    * be "collapsed", so this predicate function is necessary.
    * 
    * @return @c true if this ASTNode is a unary minus, @c false otherwise.
+   *
+   * @if clike @see SBML_parseL3Formula()@endif@~
+   * @if csharp @see SBML_parseL3Formula()@endif@~
+   * @if python @see libsbml.parseL3Formula()@endif@~
+   * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
    */
   LIBSBML_EXTERN
   bool isUMinus () const;
 
+
   /**
    * Predicate returning @c true (non-zero) if this node is a unary plus
    * operator, @c false (zero) otherwise.  A node is defined as a unary
@@ -1229,6 +1282,7 @@ public:
   LIBSBML_EXTERN
   bool isUPlus () const;
 
+
   /**
    * Predicate returning @c true (non-zero) if this node has an unknown type.
    * 
@@ -1247,6 +1301,7 @@ public:
   LIBSBML_EXTERN
   bool isUnknown () const;
 
+
   /**
    * Predicate returning @c true (non-zero) if this node has the mathml attribute
    * <code>id</code>.
@@ -1255,6 +1310,7 @@ public:
    */
   LIBSBML_EXTERN
   bool isSetId() const;
+
   
   /**
    * Predicate returning @c true (non-zero) if this node has the mathml attribute
@@ -1265,6 +1321,7 @@ public:
   LIBSBML_EXTERN
   bool isSetClass() const;
 
+
   /**
    * Predicate returning @c true (non-zero) if this node has the mathml attribute
    * <code>style</code>.
@@ -1273,6 +1330,7 @@ public:
    */
   LIBSBML_EXTERN
   bool isSetStyle() const;
+
     
   /**
    * Predicate returning @c true (non-zero) if this node has the attribute
@@ -1363,9 +1421,9 @@ public:
    * As a side-effect, this ASTNode object's type will be reset to
    * @link ASTNodeType_t#AST_NAME AST_NAME@endlink if (and <em>only
    * if</em>) the ASTNode was previously an operator (
-   * @if clike isOperator()@else ASTNode::isOperator()@endif
+   * @if clike isOperator()@else ASTNode::isOperator()@endif@~
    * <code>== true</code>), number (
-   * @if clike isNumber()@else ASTNode::isNumber()@endif
+   * @if clike isNumber()@else ASTNode::isNumber()@endif@~
    * <code>== true</code>), or unknown.
    * This allows names to be set for @link ASTNodeType_t#AST_FUNCTION
    * AST_FUNCTION@endlink nodes and the like.
@@ -1484,7 +1542,7 @@ public:
    * The units will be set @em only if this ASTNode object represents a
    * MathML <code>&lt;cn&gt;</code> element, i.e., represents a number.
    * Callers may use
-   * @if clike isNumber()@else ASTNode::isNumber()@endif
+   * @if clike isNumber()@else ASTNode::isNumber()@endif@~
    * to inquire whether the node is of that type.
    *
    * @htmlinclude about-sbml-units-attrib.html
@@ -1544,6 +1602,7 @@ public:
   virtual void replaceIDWithFunction(const std::string& id, const ASTNode* function);
   /** @endcond */
 
+
   /** @cond doxygen-libsbml-internal */
   /**
    * Replaces any 'AST_NAME_TIME' nodes with a node that multiplies time by the given function.
@@ -1577,6 +1636,7 @@ public:
   LIBSBML_EXTERN
   int unsetId ();
 
+
   /**
    * Unsets the mathml class of this ASTNode.
    *
@@ -1588,6 +1648,7 @@ public:
   LIBSBML_EXTERN
   int unsetClass ();
 
+
   /**
    * Unsets the mathml style of this ASTNode.
    *
@@ -1599,6 +1660,7 @@ public:
   LIBSBML_EXTERN
   int unsetStyle ();
 
+
   /** @cond doxygen-libsbml-internal */
 
   /**
@@ -1734,7 +1796,7 @@ public:
   *
   * @if clike
   * @see ASTNode::setUserData
-  * @endif
+  * @endif@~
   */
   LIBSBML_EXTERN
   void *getUserData() const;
@@ -2192,6 +2254,11 @@ ASTNode_isLambda (const ASTNode_t *node);
  *
  * More precisley, the node type is @c AST_FUNCTION_LOG with two children
  * the first of which is an @c AST_INTEGER equal to 10.
+ *
+ * @if clike @see SBML_parseL3Formula()@endif@~
+ * @if csharp @see SBML_parseL3Formula()@endif@~
+ * @if python @see libsbml.parseL3Formula()@endif@~
+ * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
  */
 LIBSBML_EXTERN
 int
@@ -2302,12 +2369,20 @@ ASTNode_isSqrt (const ASTNode_t *node);
  * otherwise.
  *
  * For numbers, unary minus nodes can be "collapsed" by negating the
- * number.  In fact, SBML_parseFormula() does this during its parse.
- * However, unary minus nodes for symbols (@c AST_NAMES) cannot be
- * "collapsed", so this predicate function is necessary.
+ * number.  In fact, @if clike SBML_parseFormula()@endif@if csharp SBML_parseFormula()@endif@if python libsbml.parseFormula()@endif@if java <code><a href="libsbml.html#parseFormula(java.lang.String)">libsbml.parseFormula(String formula)</a></code>@endif@~
+ * does this during its parse, and 
+ * @if clike SBML_parseL3Formula()@endif@if csharp SBML_parseL3Formula()@endif@if python libsbml.parseL3Formula()@endif@if java <code><a href="libsbml.html#parseL3Formula(java.lang.String)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
+ * has a configuration option that allows this behavior to be turned
+ * on or off.  However, unary minus nodes for symbols (@c AST_NAMES) 
+ * cannot be "collapsed", so this predicate function is necessary.
  *
  * A node is defined as a unary minus node if it is of type @c AST_MINUS
  * and has exactly one child.
+ *
+ * @if clike @see SBML_parseL3Formula()@endif@~
+ * @if csharp @see SBML_parseL3Formula()@endif@~
+ * @if python @see libsbml.parseL3Formula()@endif@~
+ * @if java @see <code><a href="libsbml.html#parseL3Formula(String formula)">libsbml.parseL3Formula(String formula)</a></code>@endif@~
  */
 LIBSBML_EXTERN
 int
