@@ -38,14 +38,15 @@
 #include <limits.h>
 #include <check.h>
 
-#if WIN32 && !defined(CYGWIN)
+#if defined(WIN32) && !defined(CYGWIN)
 #include <math.h>
 extern int isnan(double x); 
 extern int isinf(double x); 
 extern int finite(double x);
 #endif
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -2830,7 +2831,7 @@ create_suite_ASTNode (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
