@@ -32,7 +32,8 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -361,7 +362,7 @@ START_TEST (test_SBML_formulaToString)
   {
     "1",
     "2.1",
-#if WIN32 && !defined(CYGWIN)
+#if defined(WIN32) && !defined(CYGWIN)
     "2.100000e-010",
 #else
     "2.100000e-10",
@@ -641,7 +642,7 @@ create_suite_FormulaFormatter (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
