@@ -32,7 +32,7 @@
 #include <sbml/util/memory.h>
 #include <sbml/common/extern.h>
 
-#if WIN32 && !defined(CYGWIN)
+#if defined(WIN32) && !defined(CYGWIN)
 #include <math.h>
 int isnan(double x) { return x != x; }
 int isinf(double x) { return !isnan(x) && isnan(x - x); }
@@ -47,16 +47,20 @@ int finite(double x) { return !isinf(x) && !isnan(x); }
  * separate header file is not necessary and only adds a maintenance burden
  * to keep the two files synchronized.
  */
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
 Suite *create_suite_ASTNode          (void);
 Suite *create_suite_FormulaFormatter (void);
 Suite *create_suite_FormulaParser    (void);
+Suite *create_suite_L3FormulaParser  (void);
+Suite *create_suite_L3FormulaParserC (void);
 Suite *create_suite_FormulaTokenizer (void);
 Suite *create_suite_ReadMathML       (void);
 Suite *create_suite_WriteMathML      (void);
+Suite *create_suite_WriteMathMLFromAST      (void);
 
 Suite *create_suite_TestReadFromFile1      (void);
 Suite *create_suite_TestReadFromFile2      (void);
@@ -111,9 +115,12 @@ main (void)
 
   srunner_add_suite( runner, create_suite_FormulaFormatter () );
   srunner_add_suite( runner, create_suite_FormulaParser    () );
+  srunner_add_suite( runner, create_suite_L3FormulaParser  () );
+  srunner_add_suite( runner, create_suite_L3FormulaParserC () );
   srunner_add_suite( runner, create_suite_FormulaTokenizer () );
   srunner_add_suite( runner, create_suite_ReadMathML       () );
   srunner_add_suite( runner, create_suite_WriteMathML      () );
+  srunner_add_suite( runner, create_suite_WriteMathMLFromAST      () );
 
   srunner_add_suite( runner, create_suite_TestReadFromFile1() );
   srunner_add_suite( runner, create_suite_TestReadFromFile2() );
@@ -132,7 +139,7 @@ main (void)
   return num_failed;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
