@@ -29,7 +29,7 @@
 #include <sbml/extension/SBMLExtensionRegister.h>
 #include <sbml/extension/SBMLExtensionRegistry.h>
 #include <sbml/extension/SBasePluginCreator.h>
-#include <sbml/extension/SBMLDocumentPlugin.h>
+#include <sbml/extension/SBMLDocumentPluginNotRequired.h>
 #include <sbml/SBMLDocument.h>
 
 #include <sbml/packages/layout/extension/LayoutExtension.h>
@@ -126,6 +126,9 @@ const char* SBML_LAYOUT_TYPECODE_STRINGS[] =
   , "SpeciesGlyph"
   , "SpeciesReferenceGlyph"
   , "TextGlyph"
+  , "ReferenceGlyph"
+  , "GeneralGlyph"
+
 };
 
 //------------- (END) -----------------------------------
@@ -320,7 +323,7 @@ const char*
 LayoutExtension::getStringFromTypeCode(int typeCode) const
 {
   int min = SBML_LAYOUT_BOUNDINGBOX;
-  int max = SBML_LAYOUT_TEXTGLYPH;
+  int max = SBML_LAYOUT_GENERALGLYPH;
 
   if ( typeCode < min || typeCode > max)
   {
@@ -377,9 +380,6 @@ LayoutExtension::init()
   //    are required for the layout extension (The plugin class for SpeciesReference is required
   //    only for SBML Level 2) .
   //
-  //    Since only 'required' attribute is added in SBMLDocument by layout package, existing
-  //    SBMLDocumentPlugin class can be used as-is for the plugin.
-  //
   //---------------------------------------------------------------------------------------
 
   std::vector<std::string> packageURIs;
@@ -397,7 +397,7 @@ LayoutExtension::init()
   SBaseExtensionPoint sprExtPoint("core",SBML_SPECIES_REFERENCE);
   SBaseExtensionPoint msprExtPoint("core",SBML_MODIFIER_SPECIES_REFERENCE);
 
-  SBasePluginCreator<SBMLDocumentPlugin, LayoutExtension>           sbmldocPluginCreator(sbmldocExtPoint,packageURIs);
+  SBasePluginCreator<SBMLDocumentPluginNotRequired,LayoutExtension> sbmldocPluginCreator(sbmldocExtPoint,packageURIs);
   SBasePluginCreator<LayoutModelPlugin,  LayoutExtension>           modelPluginCreator(modelExtPoint,packageURIs);
   SBasePluginCreator<LayoutSpeciesReferencePlugin, LayoutExtension> sprPluginCreator(sprExtPoint,L2packageURI);
   SBasePluginCreator<LayoutSpeciesReferencePlugin, LayoutExtension> msprPluginCreator(msprExtPoint,L2packageURI);
