@@ -34,6 +34,13 @@
 #include <sbml/extension/SBMLExtensionNamespaces.h>
 #include <sbml/extension/SBMLExtensionRegister.h>
 
+
+#ifndef LAYOUT_CREATE_NS
+#define LAYOUT_CREATE_NS(variable,sbmlns)\
+  EXTENSION_CREATE_NS(LayoutPkgNamespaces,variable,sbmlns);
+#endif
+
+
 #ifdef __cplusplus
 
 #include <vector>
@@ -283,6 +290,8 @@ typedef enum
  , SBML_LAYOUT_SPECIESGLYPH          = 110    
  , SBML_LAYOUT_SPECIESREFERENCEGLYPH = 111
  , SBML_LAYOUT_TEXTGLYPH             = 112
+ , SBML_LAYOUT_REFERENCEGLYPH        = 113
+ , SBML_LAYOUT_GENERALGLYPH          = 114
 } SBMLLayoutTypeCode_t;
 
 
