@@ -566,7 +566,7 @@ const std::string& BoundingBox::getElementName () const
 /**
  * @return a (deep) copy of this Model.
  */
-SBase* 
+BoundingBox* 
 BoundingBox::clone () const
 {
     return new BoundingBox(*this);
@@ -625,7 +625,7 @@ void BoundingBox::readAttributes (const XMLAttributes& attributes,
   const unsigned int sbmlLevel   = getLevel  ();
   const unsigned int sbmlVersion = getVersion();
 
-  bool assigned = attributes.readInto("id", mId);
+  bool assigned = attributes.readInto("id", mId, getErrorLog(), false, getLine(), getColumn());
   if (assigned && mId.empty())
   {
     logEmptyString(mId, sbmlLevel, sbmlVersion, "<boundingBox>");
