@@ -48,7 +48,6 @@
  */
 
 
-#include <sbml/packages/layout/sbml/GraphicalObject.h>
 #include <sbml/packages/layout/util/LayoutUtilities.h>
 #include <sbml/SBMLErrorLog.h>
 #include <sbml/SBMLVisitor.h>
@@ -59,6 +58,7 @@
 #include <sbml/xml/XMLOutputStream.h>
 
 #include <sbml/packages/layout/extension/LayoutExtension.h>
+#include <sbml/packages/layout/common/LayoutExtensionTypes.h>
 
 LIBSBML_CPP_NAMESPACE_BEGIN
 
@@ -67,8 +67,9 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 GraphicalObject::GraphicalObject(unsigned int level, unsigned int version, unsigned int pkgVersion) 
  : SBase (level,version)
-  ,mId("")
-  ,mBoundingBox(level,version,pkgVersion)
+  , mId("")
+  , mMetaIdRef ("")
+  , mBoundingBox(level,version,pkgVersion)
 {
   setSBMLNamespacesAndOwn(new LayoutPkgNamespaces(level,version,pkgVersion));  
 }
@@ -79,8 +80,9 @@ GraphicalObject::GraphicalObject(unsigned int level, unsigned int version, unsig
  */
 GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns)
  : SBase(layoutns)
-  ,mId ("")
-  ,mBoundingBox(layoutns)
+  , mId ("")
+  , mMetaIdRef ("")
+  , mBoundingBox(layoutns)
 {
   //
   // set the element namespace of this object
@@ -101,8 +103,9 @@ GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns)
  */
 GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::string& id)
  : SBase(layoutns)
-  ,mId (id)
-  ,mBoundingBox(layoutns)
+  , mId (id)
+  , mMetaIdRef ("")
+  , mBoundingBox(layoutns)
 {
   //
   // set the element namespace of this object
@@ -126,6 +129,7 @@ GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::stri
                                   double x, double y, double w, double h)
   :  SBase(layoutns)
   , mId (id)
+  , mMetaIdRef ("")
   , mBoundingBox( BoundingBox(layoutns, "", x, y, 0.0, w, h, 0.0))
 {
   //
@@ -150,8 +154,9 @@ GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::stri
                                   double x, double y, double z,
                                   double w, double h, double d)
   : SBase(layoutns)
-  ,mId (id)
-  ,mBoundingBox( BoundingBox(layoutns, "", x, y, z, w, h, d))
+  , mId (id)
+  , mMetaIdRef ("")
+  , mBoundingBox( BoundingBox(layoutns, "", x, y, z, w, h, d))
 {
   //
   // set the element namespace of this object
@@ -176,6 +181,7 @@ GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::stri
                                   const Dimensions*  d)
   : SBase(layoutns)
   , mId (id)
+  , mMetaIdRef ("")
   , mBoundingBox( BoundingBox(layoutns, "", p, d) )
 {
   //
@@ -199,6 +205,7 @@ GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::stri
 GraphicalObject::GraphicalObject (LayoutPkgNamespaces* layoutns, const std::string& id, const BoundingBox* bb)
   : SBase(layoutns)
   , mId (id)
+  , mMetaIdRef ("")
   , mBoundingBox(layoutns)
 {
   //
@@ -273,6 +280,7 @@ GraphicalObject::GraphicalObject(const XMLNode& node, unsigned int l2version)
 GraphicalObject::GraphicalObject(const GraphicalObject& source):SBase(source)
 {
     this->mId = source.mId;
+    this->mMetaIdRef = source.mMetaIdRef;
     this->mBoundingBox=*source.getBoundingBox();
 
     connectToChild();
@@ -287,6 +295,7 @@ GraphicalObject& GraphicalObject::operator=(const GraphicalObject& source)
   {
     this->SBase::operator=(source);
     this->mId = source.mId;
+    this->mMetaIdRef = source.mMetaIdRef;
     this->mBoundingBox=*source.getBoundingBox();
 
     connectToChild();
@@ -348,6 +357,53 @@ int GraphicalObject::unsetId ()
   }
 }
 
+
+/**
+  * Returns the value of the "metaidRef" attribute of this GraphicalObject.
+  */
+const std::string& GraphicalObject::getMetaIdRef () const
+{
+  return mMetaIdRef;
+}
+
+
+/**
+  * Predicate returning @c true or @c false depending on whether this
+  * GraphicalObject's "metaidRef" attribute has been set.
+  */
+bool GraphicalObject::isSetMetaIdRef () const
+{
+  return (mMetaIdRef.empty() == false);
+}
+
+/**
+  * Sets the value of the "metaidRef" attribute of this GraphicalObject.
+  */
+int GraphicalObject::setMetaIdRef (const std::string& metaid)
+{
+  if (&metaid != NULL && metaid.empty())
+    return unsetMetaIdRef();
+  return SyntaxChecker::checkAndSetSId(metaid,mMetaIdRef);
+}
+
+
+/**
+  * Unsets the value of the "metaidRef" attribute of this GraphicalObject.
+  */
+int GraphicalObject::unsetMetaIdRef ()
+{
+  mMetaIdRef.erase();
+  if (mMetaIdRef.empty())
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+
+
 /**
  * Sets the boundingbox for the GraphicalObject.
  */ 
@@ -439,6 +495,7 @@ GraphicalObject::addExpectedAttributes(ExpectedAttributes& attributes)
   SBase::addExpectedAttributes(attributes);
 
   attributes.add("id");
+  attributes.add("metaidRef");
 }
 
 
@@ -462,6 +519,8 @@ void GraphicalObject::readAttributes (const XMLAttributes& attributes,
     logEmptyString(mId, sbmlLevel, sbmlVersion, "<" + getElementName() + ">");
   }
   if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  attributes.readInto("metaidRef", mMetaIdRef, getErrorLog(), false, getLine(), getColumn());
+  if (!SyntaxChecker::isValidInternalSId(mMetaIdRef)) logError(InvalidIdSyntax);
 }
 
 /**
@@ -499,6 +558,9 @@ void GraphicalObject::writeAttributes (XMLOutputStream& stream) const
   SBase::writeAttributes(stream);
   stream.writeAttribute("id", getPrefix(), mId);
 
+  if (isSetMetaIdRef())
+    stream.writeAttribute("metaidRef", getPrefix(), mId);
+
   //
   // (EXTENSION)
   //
@@ -596,6 +658,236 @@ GraphicalObject::enablePackageInternal(const std::string& pkgURI,
 
 
 
+/**
+ * Ctor.
+ */
+ListOfGraphicalObjects::ListOfGraphicalObjects(LayoutPkgNamespaces* layoutns)
+  : ListOf(layoutns)
+  , mElementName("listOfAdditionalGraphicalObjects")
+{
+  //
+  // set the element namespace of this object
+  //
+  setElementNamespace(layoutns->getURI());
+}
+
+
+/**
+ * Ctor.
+ */
+ListOfGraphicalObjects::ListOfGraphicalObjects(unsigned int level, unsigned int version, unsigned int pkgVersion)
+  : ListOf(level,version)
+  , mElementName("listOfAdditionalGraphicalObjects")
+{
+  setSBMLNamespacesAndOwn(new LayoutPkgNamespaces(level,version,pkgVersion));
+};
+
+
+/**
+ * @return a (deep) copy of this ListOfUnitDefinitions.
+ */
+ListOfGraphicalObjects*
+ListOfGraphicalObjects::clone () const
+{
+  return new ListOfGraphicalObjects(*this);
+}
+
+
+/**
+ * @return the typecode (int) of SBML objects contained in this ListOf or
+ * SBML_UNKNOWN (default).
+ */
+int
+ListOfGraphicalObjects::getItemTypeCode () const
+{
+  return SBML_LAYOUT_GRAPHICALOBJECT;
+}
+
+
+/**
+ * Subclasses should override this method to return XML element name of
+ * this SBML object.
+ */
+const std::string&
+ListOfGraphicalObjects::getElementName () const
+{  
+  return mElementName;
+}
+
+void 
+ListOfGraphicalObjects::setElementName(const std::string &elementName)
+{
+  mElementName = elementName;
+}
+
+
+/* return nth item in list */
+GraphicalObject *
+ListOfGraphicalObjects::get(unsigned int n)
+{
+  return static_cast<GraphicalObject*>(ListOf::get(n));
+}
+
+
+/* return nth item in list */
+const GraphicalObject *
+ListOfGraphicalObjects::get(unsigned int n) const
+{
+  return static_cast<const GraphicalObject*>(ListOf::get(n));
+}
+
+
+/* return item by id */
+GraphicalObject*
+ListOfGraphicalObjects::get (const std::string& sid)
+{
+  return const_cast<GraphicalObject*>( 
+    static_cast<const ListOfGraphicalObjects&>(*this).get(sid) );
+}
+
+
+/* return item by id */
+const GraphicalObject*
+ListOfGraphicalObjects::get (const std::string& sid) const
+{
+  std::vector<SBase*>::const_iterator result;
+
+  result = std::find_if( mItems.begin(), mItems.end(), IdEq<GraphicalObject>(sid) );
+  return (result == mItems.end()) ? 0 : static_cast <GraphicalObject*> (*result);
+}
+
+
+/* Removes the nth item from this list */
+GraphicalObject*
+ListOfGraphicalObjects::remove (unsigned int n)
+{
+   return static_cast<GraphicalObject*>(ListOf::remove(n));
+}
+
+
+/* Removes item in this list by id */
+GraphicalObject*
+ListOfGraphicalObjects::remove (const std::string& sid)
+{
+  SBase* item = 0;
+  std::vector<SBase*>::iterator result;
+
+  result = std::find_if( mItems.begin(), mItems.end(), IdEq<GraphicalObject>(sid) );
+
+  if (result != mItems.end())
+  {
+    item = *result;
+    mItems.erase(result);
+  }
+
+  return static_cast <GraphicalObject*> (item);
+}
+
+
+/**
+ * @return the SBML object corresponding to next XMLToken in the
+ * XMLInputStream or NULL if the token was not recognized.
+ */
+SBase*
+ListOfGraphicalObjects::createObject (XMLInputStream& stream)
+{
+  const std::string& name   = stream.peek().getName();
+  SBase*        object = 0;
+
+
+  if (name == "graphicalObject")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new GraphicalObject(layoutns);
+    appendAndOwn(object);
+  }
+  else if (name == "generalGlyph")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new GeneralGlyph(layoutns);
+    appendAndOwn(object);
+  }
+  else if (name == "textGlyph")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new TextGlyph(layoutns);
+    appendAndOwn(object);
+  }
+  else if (name == "speciesGlyph")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new SpeciesGlyph(layoutns);
+    appendAndOwn(object);
+  }
+  else if (name == "compartmentGlyph")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new CompartmentGlyph(layoutns);
+    appendAndOwn(object);
+  }
+  else if (name == "reactionGlyph")
+  {
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new ReactionGlyph(layoutns);
+    appendAndOwn(object);
+  }
+
+  return object;
+}
+
+bool 
+ListOfGraphicalObjects::isValidTypeForList(SBase * item)
+{
+  int tc = item->getTypeCode();
+  return ((tc == SBML_LAYOUT_COMPARTMENTGLYPH )
+    ||    (tc == SBML_LAYOUT_REACTIONGLYPH )
+    ||    (tc == SBML_LAYOUT_SPECIESGLYPH )
+    ||    (tc == SBML_LAYOUT_SPECIESREFERENCEGLYPH )
+    ||    (tc == SBML_LAYOUT_TEXTGLYPH )
+    ||    (tc == SBML_LAYOUT_GRAPHICALOBJECT )
+    ||    (tc == SBML_LAYOUT_REFERENCEGLYPH )
+    ||    (tc == SBML_LAYOUT_GENERALGLYPH )
+    );
+}
+
+/**
+ * Creates an XMLNode object from this.
+ */
+XMLNode ListOfGraphicalObjects::toXML() const
+{
+  XMLNamespaces xmlns = XMLNamespaces();
+  XMLTriple triple = XMLTriple(getElementName(), "http://projects.eml.org/bcb/sbml/level2", "");
+  XMLAttributes att = XMLAttributes();
+  XMLToken token = XMLToken(triple, att, xmlns); 
+  XMLNode node(token);
+  // add the notes and annotations
+  bool end=true;
+  if(this->mNotes)
+  {
+      node.addChild(*this->mNotes);
+      end=false;
+  }
+  if(this->mAnnotation)
+  {
+      node.addChild(*this->mAnnotation);
+      end=false;
+  }
+  unsigned int i,iMax=this->size();
+  const GraphicalObject* object=NULL;
+  for(i=0;i<iMax;++i)
+  {
+    object=dynamic_cast<const GraphicalObject*>(this->get(i));
+    assert(object);
+    node.addChild(object->toXML());
+  }
+  if(end==true && iMax==0)
+  {
+    node.setEnd();
+  }
+  return node;
+}
+
+
 
 /**
  * Creates a new GraphicalObject.
