@@ -73,6 +73,7 @@ class LIBSBML_EXTERN GraphicalObject : public SBase
 protected:
 
   std::string mId;
+  std::string mMetaIdRef;
 
   BoundingBox mBoundingBox;
         
@@ -201,6 +202,29 @@ public:
    */
   virtual int unsetId ();
 
+  /**
+   * Returns the value of the "metaidRef" attribute of this GraphicalObject.
+   */
+  virtual const std::string& getMetaIdRef () const;
+
+
+  /**
+   * Predicate returning @c true or @c false depending on whether this
+   * GraphicalObject's "metaidRef" attribute has been set.
+   */
+  virtual bool isSetMetaIdRef () const;
+
+  
+  /**
+   * Sets the value of the "metaidRef" attribute of this GraphicalObject.
+   */
+  virtual int setMetaIdRef (const std::string& metaid);
+
+
+  /**
+   * Unsets the value of the "metaidRef" attribute of this GraphicalObject.
+   */
+  virtual int unsetMetaIdRef ();
   
   /**
    * Sets the boundingbox for the GraphicalObject.
@@ -366,6 +390,155 @@ protected:
 
 };
 
+
+class LIBSBML_EXTERN ListOfGraphicalObjects : public ListOf
+{
+public:
+
+  /**
+   * @return a (deep) copy of this ListOfGraphicalObjects.
+   */
+  virtual ListOfGraphicalObjects* clone () const;
+
+
+  /**
+   * Ctor.
+   */
+   ListOfGraphicalObjects(unsigned int level      = LayoutExtension::getDefaultLevel(),
+                          unsigned int version    = LayoutExtension::getDefaultVersion(),
+                          unsigned int pkgVersion = LayoutExtension::getDefaultPackageVersion());
+
+
+  /**
+   * Ctor.
+   */
+   ListOfGraphicalObjects(LayoutPkgNamespaces* layoutns);
+
+
+  /**
+   * @return the const char* of SBML objects contained in this ListOf or
+   * SBML_UNKNOWN (default).
+   */
+  virtual int getItemTypeCode () const;
+
+  /**
+   * Subclasses should override this method to return XML element name of
+   * this SBML object.
+   */
+  virtual const std::string& getElementName () const;
+
+  /* 
+   * Allow overwriting the element name (as used by the generalGlyph)
+   */ 
+  void setElementName(const std::string& elementName);
+
+  /**
+   * Get a GraphicalObject from the ListOfGraphicalObjects.
+   *
+   * @param n the index number of the GraphicalObject to get.
+   * 
+   * @return the nth GraphicalObject in this ListOfGraphicalObjects.
+   *
+   * @see size()
+   */
+  virtual GraphicalObject * get(unsigned int n); 
+
+
+  /**
+   * Get a GraphicalObject from the ListOfGraphicalObjects.
+   *
+   * @param n the index number of the GraphicalObject to get.
+   * 
+   * @return the nth GraphicalObject in this ListOfGraphicalObjects.
+   *
+   * @see size()
+   */
+  virtual const GraphicalObject * get(unsigned int n) const; 
+
+  /**
+   * Get a GraphicalObject from the ListOfGraphicalObjects
+   * based on its identifier.
+   *
+   * @param sid a string representing the identifier 
+   * of the GraphicalObject to get.
+   * 
+   * @return GraphicalObject in this ListOfGraphicalObjects
+   * with the given id or NULL if no such
+   * GraphicalObject exists.
+   *
+   * @see get(unsigned int n)
+   * @see size()
+   */
+  virtual GraphicalObject* get (const std::string& sid);
+
+
+  /**
+   * Get a GraphicalObject from the ListOfGraphicalObjects
+   * based on its identifier.
+   *
+   * @param sid a string representing the identifier 
+   * of the GraphicalObject to get.
+   * 
+   * @return GraphicalObject in this ListOfGraphicalObjects
+   * with the given id or NULL if no such
+   * GraphicalObject exists.
+   *
+   * @see get(unsigned int n)
+   * @see size()
+   */
+  virtual const GraphicalObject* get (const std::string& sid) const;
+
+
+  /**
+   * Removes the nth item from this ListOfGraphicalObjects items and returns a pointer to
+   * it.
+   *
+   * The caller owns the returned item and is responsible for deleting it.
+   *
+   * @param n the index of the item to remove
+   *
+   * @see size()
+   */
+  virtual GraphicalObject* remove (unsigned int n);
+
+
+  /**
+   * Removes item in this ListOfGraphicalObjects items with the given identifier.
+   *
+   * The caller owns the returned item and is responsible for deleting it.
+   * If none of the items in this list have the identifier @p sid, then @c
+   * NULL is returned.
+   *
+   * @param sid the identifier of the item to remove
+   *
+   * @return the item removed.  As mentioned above, the caller owns the
+   * returned item.
+   */
+  virtual GraphicalObject* remove (const std::string& sid);
+
+
+   /**
+    * Creates an XMLNode object from this.
+    */
+    XMLNode toXML() const;
+    
+protected:
+
+  /**
+   * @return the SBML object corresponding to next XMLToken in the
+   * XMLInputStream or NULL if the token was not recognized.
+   */
+  virtual SBase* createObject (XMLInputStream& stream);
+  
+  virtual bool isValidTypeForList(SBase * item);
+
+  
+  std::string mElementName;
+
+};
+
+
+
 LIBSBML_CPP_NAMESPACE_END
 
 #endif /* __cplusplus */
