@@ -55,6 +55,7 @@
 #include <memory>
 
 #include <sbml/packages/layout/sbml/Layout.h>
+#include <sbml/packages/layout/sbml/GeneralGlyph.h>
 #include <sbml/packages/layout/util/LayoutUtilities.h>
 #include <sbml/SBMLVisitor.h>
 #include <sbml/xml/XMLNode.h>
@@ -320,6 +321,10 @@ Layout::Layout(const XMLNode& node, unsigned int l2version)
                 {
                     list.appendAndOwn(new GraphicalObject(*innerChild));
                 }
+                else if(innerChildName=="generalGlyph")
+                {
+                  list.appendAndOwn(new GeneralGlyph(*innerChild));
+                }
                 else if(innerChildName=="annotation")
                 {
                     list.setAnnotation(new XMLNode(*innerChild));
@@ -1108,7 +1113,8 @@ Layout::getNumAdditionalGraphicalObjects () const
 CompartmentGlyph* 
 Layout::createCompartmentGlyph ()
 {
-  CompartmentGlyph* p = new CompartmentGlyph(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  CompartmentGlyph* p = new CompartmentGlyph(layoutns);
 
   this->mCompartmentGlyphs.appendAndOwn(p);
   return p;
@@ -1122,7 +1128,8 @@ Layout::createCompartmentGlyph ()
 SpeciesGlyph* 
 Layout::createSpeciesGlyph ()
 {
-  SpeciesGlyph* p = new SpeciesGlyph(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  SpeciesGlyph* p = new SpeciesGlyph(layoutns);
 
   this->mSpeciesGlyphs.appendAndOwn(p);
   return p;
@@ -1136,12 +1143,27 @@ Layout::createSpeciesGlyph ()
 ReactionGlyph* 
 Layout::createReactionGlyph ()
 {
-  ReactionGlyph* p = new ReactionGlyph(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  ReactionGlyph* p = new ReactionGlyph(layoutns);
 
-  this->mReactionGlyphs.appendAndOwn(p);
+  this->mReactionGlyphs.appendAndOwn(p);  
   return p;
 }
 
+/**
+ * Creates a GeneralGlyph object, adds it to the end of the additional 
+ * objects list and returns a reference to the newly created object.
+ */
+GeneralGlyph* 
+Layout::createGeneralGlyph ()
+{
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  GeneralGlyph* g = new GeneralGlyph(layoutns);
+
+  this->mAdditionalGraphicalObjects.appendAndOwn(g);
+  return g;
+}
+
 
 /**
  * Creates a TextGlyph object, adds it to the end of the text glyph objects
@@ -1150,7 +1172,8 @@ Layout::createReactionGlyph ()
 TextGlyph* 
 Layout::createTextGlyph ()
 {
-  TextGlyph* p = new TextGlyph(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  TextGlyph* p = new TextGlyph(layoutns);
 
   this->mTextGlyphs.appendAndOwn(p);
   return p;
@@ -1165,7 +1188,8 @@ Layout::createTextGlyph ()
 GraphicalObject* 
 Layout::createAdditionalGraphicalObject ()
 {
-  GraphicalObject* p = new GraphicalObject(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  GraphicalObject* p = new GraphicalObject(layoutns);
 
   this->mAdditionalGraphicalObjects.appendAndOwn(p);
   return p;
@@ -1662,19 +1686,8 @@ ListOfLayouts::createObject (XMLInputStream& stream)
 
   if (name == "layout")
   {
-    SBMLNamespaces* sbmlns = this->getSBMLNamespaces();
-    XMLNamespaces* xmlns = sbmlns->getNamespaces();
-    LayoutPkgNamespaces* layoutns1 = dynamic_cast<LayoutPkgNamespaces*>(sbmlns);
-    if (layoutns1 == NULL)
-    {
-       layoutns1 = new LayoutPkgNamespaces(sbmlns->getLevel(), sbmlns->getVersion());
-       for (int i = 0; i < xmlns->getNumNamespaces(); i++)
-       {         
-         if (!layoutns1->getNamespaces()->hasURI(xmlns->getURI(i)))
-           layoutns1->getNamespaces()->add(xmlns->getURI(i), xmlns->getPrefix(i));
-       }
-    }
-    object = new Layout(layoutns1);
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new Layout(layoutns);
     appendAndOwn(object);
     //mItems.push_back(object);
   }
@@ -1875,7 +1888,8 @@ ListOfCompartmentGlyphs::createObject (XMLInputStream& stream)
 
   if (name == "compartmentGlyph")
   {
-    object = new CompartmentGlyph(static_cast<LayoutPkgNamespaces*>(mSBMLNamespaces));
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new CompartmentGlyph(layoutns);
     appendAndOwn(object);
 //    mItems.push_back(object);
   }
@@ -2056,7 +2070,8 @@ ListOfSpeciesGlyphs::createObject (XMLInputStream& stream)
 
   if (name == "speciesGlyph")
   {
-    object = new SpeciesGlyph();
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new SpeciesGlyph(layoutns);
     appendAndOwn(object);
 //    mItems.push_back(object);
   }
@@ -2234,7 +2249,8 @@ ListOfReactionGlyphs::createObject (XMLInputStream& stream)
 
   if (name == "reactionGlyph")
   {
-    object = new ReactionGlyph();
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new ReactionGlyph(layoutns);
     appendAndOwn(object);
 //    mItems.push_back(object);
   }
@@ -2412,7 +2428,8 @@ ListOfTextGlyphs::createObject (XMLInputStream& stream)
 
   if (name == "textGlyph")
   {
-    object = new TextGlyph();
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new TextGlyph(layoutns);
     appendAndOwn(object);
 //    mItems.push_back(object);
   }
@@ -2458,209 +2475,6 @@ XMLNode ListOfTextGlyphs::toXML() const
 }
 
 
-/**
- * Ctor.
- */
-ListOfGraphicalObjects::ListOfGraphicalObjects(LayoutPkgNamespaces* layoutns)
-  : ListOf(layoutns)
-{
-  //
-  // set the element namespace of this object
-  //
-  setElementNamespace(layoutns->getURI());
-}
-
-
-/**
- * Ctor.
- */
-ListOfGraphicalObjects::ListOfGraphicalObjects(unsigned int level, unsigned int version, unsigned int pkgVersion)
-  : ListOf(level,version)
-{
-  setSBMLNamespacesAndOwn(new LayoutPkgNamespaces(level,version,pkgVersion));
-};
-
-
-/**
- * @return a (deep) copy of this ListOfUnitDefinitions.
- */
-ListOfGraphicalObjects*
-ListOfGraphicalObjects::clone () const
-{
-  return new ListOfGraphicalObjects(*this);
-}
-
-
-/**
- * @return the typecode (int) of SBML objects contained in this ListOf or
- * SBML_UNKNOWN (default).
- */
-int
-ListOfGraphicalObjects::getItemTypeCode () const
-{
-  return SBML_LAYOUT_GRAPHICALOBJECT;
-}
-
-
-/**
- * Subclasses should override this method to return XML element name of
- * this SBML object.
- */
-const std::string&
-ListOfGraphicalObjects::getElementName () const
-{
-  static const std::string name = "listOfAdditionalGraphicalObjects";
-  return name;
-}
-
-
-/* return nth item in list */
-GraphicalObject *
-ListOfGraphicalObjects::get(unsigned int n)
-{
-  return static_cast<GraphicalObject*>(ListOf::get(n));
-}
-
-
-/* return nth item in list */
-const GraphicalObject *
-ListOfGraphicalObjects::get(unsigned int n) const
-{
-  return static_cast<const GraphicalObject*>(ListOf::get(n));
-}
-
-
-/* return item by id */
-GraphicalObject*
-ListOfGraphicalObjects::get (const std::string& sid)
-{
-  return const_cast<GraphicalObject*>( 
-    static_cast<const ListOfGraphicalObjects&>(*this).get(sid) );
-}
-
-
-/* return item by id */
-const GraphicalObject*
-ListOfGraphicalObjects::get (const std::string& sid) const
-{
-  std::vector<SBase*>::const_iterator result;
-
-  result = std::find_if( mItems.begin(), mItems.end(), IdEq<GraphicalObject>(sid) );
-  return (result == mItems.end()) ? 0 : static_cast <GraphicalObject*> (*result);
-}
-
-
-/* Removes the nth item from this list */
-GraphicalObject*
-ListOfGraphicalObjects::remove (unsigned int n)
-{
-   return static_cast<GraphicalObject*>(ListOf::remove(n));
-}
-
-
-/* Removes item in this list by id */
-GraphicalObject*
-ListOfGraphicalObjects::remove (const std::string& sid)
-{
-  SBase* item = 0;
-  std::vector<SBase*>::iterator result;
-
-  result = std::find_if( mItems.begin(), mItems.end(), IdEq<GraphicalObject>(sid) );
-
-  if (result != mItems.end())
-  {
-    item = *result;
-    mItems.erase(result);
-  }
-
-  return static_cast <GraphicalObject*> (item);
-}
-
-
-/**
- * @return the SBML object corresponding to next XMLToken in the
- * XMLInputStream or NULL if the token was not recognized.
- */
-SBase*
-ListOfGraphicalObjects::createObject (XMLInputStream& stream)
-{
-  const std::string& name   = stream.peek().getName();
-  SBase*        object = 0;
-
-
-  if (name == "graphicalObject")
-  {
-    SBMLNamespaces* sbmlns = this->getSBMLNamespaces();
-    XMLNamespaces* xmlns = sbmlns->getNamespaces();
-    LayoutPkgNamespaces* layoutns1 = dynamic_cast<LayoutPkgNamespaces*>(sbmlns);
-    if (layoutns1 == NULL)
-    {
-       layoutns1 = new LayoutPkgNamespaces(sbmlns->getLevel(), sbmlns->getVersion());
-       for (int i = 0; i < xmlns->getNumNamespaces(); i++)
-       {         
-         if (!layoutns1->getNamespaces()->hasURI(xmlns->getURI(i)))
-           layoutns1->getNamespaces()->add(xmlns->getURI(i), xmlns->getPrefix(i));
-       }
-    }
-
-    object = new GraphicalObject(layoutns1);
-    appendAndOwn(object);
-//    mItems.push_back(object);
-  }
-
-  return object;
-}
-
-bool 
-ListOfGraphicalObjects::isValidTypeForList(SBase * item)
-{
-  int tc = item->getTypeCode();
-  return ((tc == SBML_LAYOUT_COMPARTMENTGLYPH )
-    ||    (tc == SBML_LAYOUT_REACTIONGLYPH )
-    ||    (tc == SBML_LAYOUT_SPECIESGLYPH )
-    ||    (tc == SBML_LAYOUT_SPECIESREFERENCEGLYPH )
-    ||    (tc == SBML_LAYOUT_TEXTGLYPH )
-    ||    (tc == SBML_LAYOUT_GRAPHICALOBJECT ));
-}
-
-/**
- * Creates an XMLNode object from this.
- */
-XMLNode ListOfGraphicalObjects::toXML() const
-{
-  XMLNamespaces xmlns = XMLNamespaces();
-  XMLTriple triple = XMLTriple("listOfAdditionalGraphicalObjects", "http://projects.eml.org/bcb/sbml/level2", "");
-  XMLAttributes att = XMLAttributes();
-  XMLToken token = XMLToken(triple, att, xmlns); 
-  XMLNode node(token);
-  // add the notes and annotations
-  bool end=true;
-  if(this->mNotes)
-  {
-      node.addChild(*this->mNotes);
-      end=false;
-  }
-  if(this->mAnnotation)
-  {
-      node.addChild(*this->mAnnotation);
-      end=false;
-  }
-  unsigned int i,iMax=this->size();
-  const GraphicalObject* object=NULL;
-  for(i=0;i<iMax;++i)
-  {
-    object=dynamic_cast<const GraphicalObject*>(this->get(i));
-    assert(object);
-    node.addChild(object->toXML());
-  }
-  if(end==true && iMax==0)
-  {
-    node.setEnd();
-  }
-  return node;
-}
-
-
 
 
 
@@ -3046,6 +2860,18 @@ Layout_createReactionGlyph (Layout_t *l)
   return l->createReactionGlyph();
 }
 
+/**
+ * Creates a GeneralGlyph_t object, adds it to the end of the additional
+ * objects list and returns a pointer to the newly created object.
+ */
+LIBSBML_EXTERN
+GeneralGlyph_t *
+Layout_createGeneralGlyph (Layout_t *l)
+{
+  return l->createGeneralGlyph();
+}
+
+
 
 /**
  * Creates a TextGlyph_t object, adds it to the end of the text glyphs
