@@ -621,145 +621,6 @@ protected:
   virtual SBase* createObject (XMLInputStream& stream);
 };
 
-class LIBSBML_EXTERN ListOfGraphicalObjects : public ListOf
-{
-public:
-
-  /**
-   * @return a (deep) copy of this ListOfGraphicalObjects.
-   */
-  virtual ListOfGraphicalObjects* clone () const;
-
-
-  /**
-   * Ctor.
-   */
-   ListOfGraphicalObjects(unsigned int level      = LayoutExtension::getDefaultLevel(),
-                          unsigned int version    = LayoutExtension::getDefaultVersion(),
-                          unsigned int pkgVersion = LayoutExtension::getDefaultPackageVersion());
-
-
-  /**
-   * Ctor.
-   */
-   ListOfGraphicalObjects(LayoutPkgNamespaces* layoutns);
-
-
-  /**
-   * @return the const char* of SBML objects contained in this ListOf or
-   * SBML_UNKNOWN (default).
-   */
-  virtual int getItemTypeCode () const;
-
-  /**
-   * Subclasses should override this method to return XML element name of
-   * this SBML object.
-   */
-  virtual const std::string& getElementName () const;
-
-
-  /**
-   * Get a GraphicalObject from the ListOfGraphicalObjects.
-   *
-   * @param n the index number of the GraphicalObject to get.
-   * 
-   * @return the nth GraphicalObject in this ListOfGraphicalObjects.
-   *
-   * @see size()
-   */
-  virtual GraphicalObject * get(unsigned int n); 
-
-
-  /**
-   * Get a GraphicalObject from the ListOfGraphicalObjects.
-   *
-   * @param n the index number of the GraphicalObject to get.
-   * 
-   * @return the nth GraphicalObject in this ListOfGraphicalObjects.
-   *
-   * @see size()
-   */
-  virtual const GraphicalObject * get(unsigned int n) const; 
-
-  /**
-   * Get a GraphicalObject from the ListOfGraphicalObjects
-   * based on its identifier.
-   *
-   * @param sid a string representing the identifier 
-   * of the GraphicalObject to get.
-   * 
-   * @return GraphicalObject in this ListOfGraphicalObjects
-   * with the given id or NULL if no such
-   * GraphicalObject exists.
-   *
-   * @see get(unsigned int n)
-   * @see size()
-   */
-  virtual GraphicalObject* get (const std::string& sid);
-
-
-  /**
-   * Get a GraphicalObject from the ListOfGraphicalObjects
-   * based on its identifier.
-   *
-   * @param sid a string representing the identifier 
-   * of the GraphicalObject to get.
-   * 
-   * @return GraphicalObject in this ListOfGraphicalObjects
-   * with the given id or NULL if no such
-   * GraphicalObject exists.
-   *
-   * @see get(unsigned int n)
-   * @see size()
-   */
-  virtual const GraphicalObject* get (const std::string& sid) const;
-
-
-  /**
-   * Removes the nth item from this ListOfGraphicalObjects items and returns a pointer to
-   * it.
-   *
-   * The caller owns the returned item and is responsible for deleting it.
-   *
-   * @param n the index of the item to remove
-   *
-   * @see size()
-   */
-  virtual GraphicalObject* remove (unsigned int n);
-
-
-  /**
-   * Removes item in this ListOfGraphicalObjects items with the given identifier.
-   *
-   * The caller owns the returned item and is responsible for deleting it.
-   * If none of the items in this list have the identifier @p sid, then @c
-   * NULL is returned.
-   *
-   * @param sid the identifier of the item to remove
-   *
-   * @return the item removed.  As mentioned above, the caller owns the
-   * returned item.
-   */
-  virtual GraphicalObject* remove (const std::string& sid);
-
-
-   /**
-    * Creates an XMLNode object from this.
-    */
-    XMLNode toXML() const;
-    
-protected:
-
-  /**
-   * @return the SBML object corresponding to next XMLToken in the
-   * XMLInputStream or NULL if the token was not recognized.
-   */
-  virtual SBase* createObject (XMLInputStream& stream);
-  
-  virtual bool isValidTypeForList(SBase * item);
-};
-
-
 class LIBSBML_EXTERN Layout : public SBase
 {
 protected:
@@ -1168,6 +1029,12 @@ public:
   
   ReactionGlyph* createReactionGlyph ();
 
+  /**
+   * Creates a GeneralGlyph object, adds it to the end of the additional 
+   * objects list and returns a reference to the newly created object.
+   */
+  GeneralGlyph*  createGeneralGlyph();
+
   /**
    * Creates a TextGlyph object, adds it to the end of the text glyph
    * objects list and returns a pointer to the newly created object.
@@ -1191,6 +1058,7 @@ public:
   
   SpeciesReferenceGlyph* createSpeciesReferenceGlyph();
 
+
   /**
    * Creates a new LineSegment for the Curve object of the last
    * ReactionGlyph or the last SpeciesReferenceGlyph in the last
@@ -1938,6 +1806,14 @@ LIBSBML_EXTERN
 ReactionGlyph_t *
 Layout_createReactionGlyph (Layout_t *);
 
+/**
+ * Creates a GeneralGlyph_t object, adds it to the end of the additional
+ * objects list and returns a pointer to the newly created object.
+ */
+LIBSBML_EXTERN
+GeneralGlyph_t *
+Layout_createGeneralGlyph (Layout_t *);
+
 
 /**
  * Creates a TextGlyph_t object, adds it to the end of the text glyphs
