@@ -457,7 +457,8 @@ bool ReactionGlyph::isSetCurve () const
 SpeciesReferenceGlyph*
 ReactionGlyph::createSpeciesReferenceGlyph ()
 {
-  SpeciesReferenceGlyph* srg = new SpeciesReferenceGlyph();
+  LAYOUT_CREATE_NS(layoutns,getSBMLNamespaces());
+  SpeciesReferenceGlyph* srg = new SpeciesReferenceGlyph(layoutns);
 
   this->mSpeciesReferenceGlyphs.appendAndOwn(srg);
   return srg;
@@ -865,7 +866,8 @@ ListOfSpeciesReferenceGlyphs::createObject (XMLInputStream& stream)
 
   if (name == "speciesReferenceGlyph")
   {
-    object = new SpeciesReferenceGlyph();
+    LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
+    object = new SpeciesReferenceGlyph(layoutns);
     appendAndOwn(object);
 //    mItems.push_back(object);
   }
