@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2009-2011 jointly by the following organizations: 
+ * Copyright (C) 2009-2012 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
  *  
@@ -43,12 +43,17 @@
 #include <sbml/Reaction.h>
 #include <sbml/SBMLDocument.h>
 #include <sbml/Species.h>
-#include <sbml/SpeciesReference.h>
+#include <sbml/ModifierSpeciesReference.h>
 #include <sbml/SpeciesType.h>
 #include <sbml/Unit.h>
 #include <sbml/UnitDefinition.h>
 #include <sbml/units/FormulaUnitsData.h>
 
+
+#include <sbml/AlgebraicRule.h>
+#include <sbml/AssignmentRule.h>
+#include <sbml/RateRule.h>
+
 #include <sbml/math/ASTNode.h>
 
 #include <check.h>
