@@ -38,6 +38,9 @@
 
 #include <sbml/common/extern.h>
 
+LIBSBML_CPP_NAMESPACE_USE
+
+
 BEGIN_C_DECLS
 
 static KineticLaw_t *KL;
@@ -135,7 +138,7 @@ START_TEST (test_L3_KineticLaw_addParameter2)
   fail_unless( KineticLaw_getNumParameters(kl) == 1);
   fail_unless( KineticLaw_getNumLocalParameters(kl) == 1);
 
-  i = KineticLaw_addParameter(kl, lp1);
+  i = KineticLaw_addParameter(kl, (Parameter_t *)lp1);
   fail_unless( i == LIBSBML_OPERATION_SUCCESS);
   fail_unless( KineticLaw_getNumParameters(kl) == 2);
   fail_unless( KineticLaw_getNumLocalParameters(kl) == 2);
