@@ -41,9 +41,12 @@
 
 #include <sbml/common/extern.h>
 
+LIBSBML_CPP_NAMESPACE_USE
+
+
 BEGIN_C_DECLS
 
-#if WIN32 && !defined(CYGWIN)
+#if defined(WIN32) && !defined(CYGWIN)
 int isnan(double x);
 int isinf(double x);
 int finite(double x);
@@ -433,7 +436,7 @@ END_TEST
 START_TEST (test_L3_Species_ModelHistory)
 {
   ModelHistory_t * history = ModelHistory_create();
-  
+  SBase_setMetaId((SBase_t *)(S), "_3");
   int i = SBase_setModelHistory((SBase_t *)(S), history);
 
   fail_unless( i == LIBSBML_INVALID_OBJECT );
