@@ -36,9 +36,11 @@
 
 #include <sbml/common/extern.h>
 
+LIBSBML_CPP_NAMESPACE_USE
+
 BEGIN_C_DECLS
 
-#if WIN32 && !defined(CYGWIN)
+#if defined(WIN32) && !defined(CYGWIN)
 int isnan(double x);
 int isinf(double x);
 int finite(double x);
