@@ -36,6 +36,9 @@
 
 #include <sbml/common/extern.h>
 
+LIBSBML_CPP_NAMESPACE_USE
+
+
 BEGIN_C_DECLS
 
 static Model_t *M;
@@ -188,6 +191,7 @@ END_TEST
 
 START_TEST(test_Model_setgetModelHistory)
 {
+  SBase_setMetaId((SBase_t *) (M), "_001");
   ModelHistory_t * history = ModelHistory_create();
   ModelCreator_t * mc = ModelCreator_create();
   Date_t * date = 
