@@ -55,6 +55,9 @@
 
 #include <sbml/common/extern.h>
 
+LIBSBML_CPP_NAMESPACE_USE
+
+
 BEGIN_C_DECLS
 
 static Model_t *M;
@@ -178,6 +181,7 @@ END_TEST
 
 START_TEST (test_Model_setModelHistory1)
 {
+  SBase_setMetaId((SBase_t *) (M), "_001");
   ModelHistory_t *mh = ModelHistory_create();
   int i = Model_setModelHistory(M, mh);
 
@@ -196,6 +200,7 @@ END_TEST
 
 START_TEST (test_Model_setModelHistory2)
 {
+  SBase_setMetaId((SBase_t *) (M), "_001");
   int i = Model_setModelHistory(M, NULL);
 
   fail_unless( i == LIBSBML_OPERATION_SUCCESS );
