@@ -196,12 +196,13 @@ START_TEST (test_ReadSBML_Model_withoutEncoding)
   fail_unless( !strcmp(Model_getId(M), "testModel") );
   fail_unless (SBMLDocument_getNumErrors(D) == 0);
 
+  /*
   const char* s2 = 
     "<?xml version='1.0' encoding='UTF-8'?>\n"
     "<sbml level='2' version='1' xmlns='http://www.sbml.org/sbml/level2'>"
     "  <model id='testModel'></model>"
     "</sbml>";
-
+  */
 
   D = readSBMLFromString(s);
   M = SBMLDocument_getModel(D);
@@ -2565,6 +2566,21 @@ START_TEST (test_ReadSBML_line_col_numbers)
   fail_unless ( SBase_getLine  (sb) ==  4 );
   fail_unless ( SBase_getColumn(sb) == 34 );
 #endif
+
+  /* NULL test */
+  sb = NULL;
+#ifdef USE_EXPAT
+  fail_unless ( SBase_getLine  (sb) == 0 );
+  fail_unless ( SBase_getColumn(sb) == 0 );
+#endif
+#ifdef USE_LIBXML
+  fail_unless ( SBase_getLine  (sb) == 0 );
+  fail_unless ( SBase_getColumn(sb) == 0 ); 
+#endif
+#ifdef USE_XERCES
+  fail_unless ( SBase_getLine  (sb) ==  0 );
+  fail_unless ( SBase_getColumn(sb) == 0 );
+#endif
 }
 END_TEST
 
