@@ -42,6 +42,14 @@
 LIBSBML_CPP_NAMESPACE_USE
 
 
+/*
+ * We create a lot of strings in this file, for testing, and we don't 
+ * do what this warning tries to help with, so we shut it up just
+ * for this file.
+ */
+#pragma GCC diagnostic ignored "-Wwrite-strings"
+
+
 BEGIN_C_DECLS
 
 static SBase *S;
@@ -2250,6 +2258,103 @@ START_TEST(test_SBase_matchesSBMLNamespaces)
   delete s;
   delete p;
   delete c;
+}
+END_TEST
+
+START_TEST(test_SBase_matchesRequiredSBMLNamespacesForAddition)
+{
+  SBMLNamespaces *sbmlns1 = new SBMLNamespaces(3,1);
+  SBMLNamespaces *sbmlns2 = new SBMLNamespaces(2,4);
+
+  Species * s = new Species(sbmlns1);
+  Parameter * p = new Parameter(sbmlns1);
+
+  fail_unless(s->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == true);
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(s)) == true);
+
+  p = new Parameter(sbmlns2);
+
+  fail_unless(s->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == false);
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(s)) == false);
+
+  sbmlns1->addNamespace("http:foo", "bar");
+
+  Compartment *c = new Compartment(sbmlns1);
+
+  fail_unless(s->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == true);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(s)) == true);
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == false);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == false);
+
+  sbmlns1->addNamespace("http://www.sbml.org/sbml/level3/version1/qual/version1", "bar1");
+  s = new Species(sbmlns1);
+
+  fail_unless(s->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == true);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(s)) == false);
+
+  sbmlns2 = new SBMLNamespaces(3,1);
+  sbmlns2->addNamespace("http://www.sbml.org/sbml/level3/version1/qual/version1", "bar1");
+  c = new Compartment(sbmlns2);
+
+  fail_unless(s->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == true);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(s)) == true);
+
+  sbmlns1 = new SBMLNamespaces(3,1);
+  p = new Parameter(sbmlns1);
+
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == false);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == true);
+
+  sbmlns1->addNamespace("http://www.sbml.org/sbml/level3/version1/qual/version2", "bar2");
+  p = new Parameter(sbmlns1);
+
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == false);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == false);
+
+  sbmlns1 = new SBMLNamespaces(3,1);
+  sbmlns1->addNamespace("http://www.sbml.org/sbml/level3/version1/qual/version1", "bar1");
+  sbmlns1->removeNamespace(SBMLNamespaces::getSBMLNamespaceURI(3,1));
+  p = new Parameter(sbmlns1);
+
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == false);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == false);
+
+  sbmlns1 = new SBMLNamespaces(3,1);
+  sbmlns1->addNamespace("http://www.sbml.org/sbml/level3/version1/qual/version1", "bar1");
+  sbmlns1->addNamespace("http://www.sbml.org/sbml/level3/version1/comp/version1", "comp");
+  p = new Parameter(sbmlns1);
+
+  fail_unless(p->matchesRequiredSBMLNamespacesForAddition((SBase *)(c)) == true);
+  fail_unless(c->matchesRequiredSBMLNamespacesForAddition((SBase *)(p)) == false);
+
+  delete s;
+  delete p;
+  delete c;
+}
+END_TEST
+
+START_TEST(test_SBase_prefixMetaIdSBO)
+{
+  Species species(3,1);
+  species.setMetaId("meta1");
+  species.setSBOTerm(245);
+
+  std::string noPrefix = species.toSBML();
+  fail_unless (noPrefix.find(" metaid=") != std::string::npos);
+  fail_unless (noPrefix.find(" sboTerm=") != std::string::npos);
+
+  species.getNamespaces()->remove("");
+  species.getNamespaces()->add(SBMLNamespaces::getSBMLNamespaceURI(3, 1), "l3v1");
+  
+  std::string prefix = species.toSBML();
+  fail_unless (prefix.find(" l3v1:metaid=") != std::string::npos);
+  fail_unless (prefix.find(" l3v1:sboTerm=") != std::string::npos);
+
+  fail_unless (noPrefix != prefix);
+  
+
+
+
 }
 END_TEST
 
@@ -2294,6 +2399,7 @@ create_suite_SBase (void)
   tcase_add_test(tcase, test_SBase_setMetaId     );
  // tcase_add_test(tcase, test_SBase_setNotes      );
   tcase_add_test(tcase, test_SBase_setAnnotation );
+  tcase_add_test(tcase, test_SBase_setNotes);
   tcase_add_test(tcase, test_SBase_setNotesString);
   tcase_add_test(tcase, test_SBase_setAnnotationString);
   tcase_add_test(tcase, test_SBase_unsetAnnotationWithCVTerms );
@@ -2326,8 +2432,11 @@ create_suite_SBase (void)
   tcase_add_test(tcase, test_SBase_getQualifiersFromResources );
   tcase_add_test(tcase, test_SBase_hasValidLevelVersionNamespaceCombination);
   tcase_add_test(tcase, test_SBase_matchesSBMLNamespaces);
+  tcase_add_test(tcase, test_SBase_matchesRequiredSBMLNamespacesForAddition);
   tcase_add_test(tcase, test_SBase_userData);
 
+  tcase_add_test(tcase, test_SBase_prefixMetaIdSBO);
+
   suite_add_tcase(suite, tcase);
 
   return suite;
