@@ -98,7 +98,7 @@ public:
    *
    * @param orig the object to copy.
    * 
-   * @throws @if python ValueError @else SBMLConstructorException @endif
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
    * Thrown if the argument @p orig is @c NULL.
    */
   FormulaUnitsData(const FormulaUnitsData& orig);
@@ -110,7 +110,7 @@ public:
    * @param rhs The object whose values are used as the basis of the
    * assignment.
    *
-   * @throws @if python ValueError @else SBMLConstructorException @endif
+   * @throws @if python ValueError @else SBMLConstructorException @endif@~
    * Thrown if the argument @p rhs is @c NULL.
    */
   FormulaUnitsData& operator=(const FormulaUnitsData& rhs);
@@ -167,7 +167,7 @@ public:
    * @return the value of the SBMLTypeCode_t of this 
    * FormulaUnitsData.
    */
-  const int getComponentTypecode() const;
+  int getComponentTypecode() const;
 
 
   /**
@@ -187,7 +187,7 @@ public:
    * @return @c true if the FormulaUnitsData includes parameters/numbers 
    * with undeclared units, @c false otherwise.
    */
-  const bool getContainsUndeclaredUnits() const;
+  bool getContainsUndeclaredUnits() const;
 
 
   /**
@@ -225,7 +225,7 @@ public:
    * @return @c true if the parameters/numbers 
    * with undeclared units can be ignored, @c false otherwise.
    */
-  const bool getCanIgnoreUndeclaredUnits() const;
+  bool getCanIgnoreUndeclaredUnits() const;
 
 
   /**
