@@ -27,8 +27,11 @@
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ---------------------------------------------------------------------- -->*/
 
-#include <sbml/SBMLTypes.h>
 #include "IdBase.h"
+#include <sbml/AssignmentRule.h>
+#include <sbml/RateRule.h>
+#include <sbml/AlgebraicRule.h>
+#include <sbml/ModifierSpeciesReference.h>
 
 /** @cond doxygen-ignored */
 
