@@ -31,12 +31,14 @@
 
 //#include <string>
 
-#include <sbml/SBMLTypes.h>
 #include <sbml/SBMLTypeCodes.h>
 #include <sbml/SBO.h>
 #include <sbml/validator/VConstraint.h>
 #include <sbml/units/UnitFormulaFormatter.h>
 #include <sbml/units/FormulaUnitsData.h>
+#include <sbml/AssignmentRule.h>
+#include <sbml/RateRule.h>
+#include <sbml/AlgebraicRule.h>
 
 #include <sbml/util/List.h>
 
