@@ -57,7 +57,7 @@ trim (const std::string& s)
   std::string::size_type begin = s.find_first_not_of(whitespace);
   std::string::size_type end   = s.find_last_not_of (whitespace);
 
-  return (begin == std::string::npos) ? "" : s.substr(begin, end - begin + 1);
+  return (begin == std::string::npos) ? std::string() : s.substr(begin, end - begin + 1);
 }
 
 
@@ -348,7 +348,7 @@ XMLAttributes::getNumAttributes () const
 std::string
 XMLAttributes::getName (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNames[index].getName();
+  return (index < 0 || index >= getLength()) ? std::string() : mNames[index].getName();
 }
 
 
@@ -360,7 +360,7 @@ XMLAttributes::getName (int index) const
 std::string
 XMLAttributes::getPrefix (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNames[index].getPrefix();
+  return (index < 0 || index >= getLength()) ? std::string() : mNames[index].getPrefix();
 }
 
 
@@ -373,7 +373,7 @@ XMLAttributes::getPrefix (int index) const
 std::string
 XMLAttributes::getPrefixedName (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNames[index].getPrefixedName();
+  return (index < 0 || index >= getLength()) ? std::string() : mNames[index].getPrefixedName();
 }
 
 
@@ -385,7 +385,7 @@ XMLAttributes::getPrefixedName (int index) const
 std::string
 XMLAttributes::getURI (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNames[index].getURI();
+  return (index < 0 || index >= getLength()) ? std::string() : mNames[index].getURI();
 }
 
 
@@ -397,7 +397,7 @@ XMLAttributes::getURI (int index) const
 std::string
 XMLAttributes::getValue (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mValues[index];
+  return (index < 0 || index >= getLength()) ? std::string() : mValues[index];
 }
 
 
@@ -1332,7 +1332,7 @@ XMLAttributes_clone (const XMLAttributes_t* att)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -1363,7 +1363,7 @@ XMLAttributes_add (XMLAttributes_t *xa,
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -1393,7 +1393,7 @@ XMLAttributes_addWithNamespace (XMLAttributes_t *xa,
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -1438,7 +1438,7 @@ XMLAttributes_addResource (XMLAttributes_t *xa,
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -1461,7 +1461,7 @@ XMLAttributes_removeResource (XMLAttributes_t *xa, int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -1484,7 +1484,7 @@ XMLAttributes_remove (XMLAttributes_t *xa, int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -1514,7 +1514,7 @@ XMLAttributes_removeByName (XMLAttributes_t *xa, const char* name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -1538,7 +1538,7 @@ XMLAttributes_removeByNS (XMLAttributes_t *xa, const char* name, const char* uri
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -1560,7 +1560,7 @@ XMLAttributes_removeByTriple (XMLAttributes_t *xa, const XMLTriple_t* triple)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
