@@ -279,7 +279,7 @@ XMLNamespaces::getNumNamespaces () const
 std::string
 XMLNamespaces::getPrefix (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNamespaces[index].first;
+  return (index < 0 || index >= getLength()) ? std::string() : mNamespaces[index].first;
 }
 
 
@@ -302,7 +302,7 @@ XMLNamespaces::getPrefix (const std::string& uri) const
 std::string
 XMLNamespaces::getURI (int index) const
 {
-  return (index < 0 || index >= getLength()) ? "" : mNamespaces[index].second;
+  return (index < 0 || index >= getLength()) ? std::string() : mNamespaces[index].second;
 }
 
 
@@ -314,13 +314,13 @@ XMLNamespaces::getURI (int index) const
 std::string
 XMLNamespaces::getURI (const std::string& prefix) const
 {
-  if (&prefix == NULL) return "";
+  if (&prefix == NULL) return std::string();
   for (int index = 0; index < getLength(); ++index)
   {
     if (getPrefix(index) == prefix) return getURI(index);
   }
   
-  return "";
+  return std::string();
 }
 
 
@@ -519,7 +519,7 @@ XMLNamespaces_clone (const XMLNamespaces_t* ns)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -542,7 +542,7 @@ XMLNamespaces_add (XMLNamespaces_t *ns,
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -563,7 +563,7 @@ int XMLNamespaces_remove (XMLNamespaces_t *ns, int index)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INDEX_EXCEEDS_SIZE
@@ -585,7 +585,7 @@ int XMLNamespaces_removeByPrefix (XMLNamespaces_t *ns, const char* prefix)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
