@@ -57,7 +57,7 @@ trim (const string& s)
   string::size_type begin = s.find_first_not_of(whitespace);
   string::size_type end   = s.find_last_not_of (whitespace);
 
-  return (begin == string::npos) ? "" : s.substr(begin, end - begin + 1);
+  return (begin == string::npos) ? std::string() : s.substr(begin, end - begin + 1);
 }
 
 
@@ -501,9 +501,25 @@ XMLNode::write (XMLOutputStream& stream) const
 
   if (children > 0)
   {
-    for (unsigned int c = 0; c < children; ++c) stream << getChild(c);
+    bool haveTextNode = false;
+    for (unsigned int c = 0; c < children; ++c) 
+    {
+        const XMLNode& current = getChild(c);
+        stream << current;
+        haveTextNode |= current.isText();
+    }
+
     if (!mTriple.isEmpty())
+    {
+      // edge case ... we have an element with a couple of elements, and 
+      // one is a text node (ugly!) in this case we can get a hanging
+      // indent ... so we downindent ... 
+      if (children > 1 && haveTextNode)
+      {
+        stream.downIndent();
+      }
       stream.endElement( mTriple );
+    }
   }
   else if ( isStart() && !isEnd() ) 
   {
@@ -784,7 +800,7 @@ XMLNode_free (XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -848,7 +864,7 @@ XMLNode_removeChild(XMLNode_t *node, unsigned int n)
  * @param n an integer the index of the resource to be deleted
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_OBJECT
@@ -887,7 +903,7 @@ XMLNode_getCharacters (const XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1118,7 +1134,7 @@ XMLNode_getAttributes (const XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1146,7 +1162,7 @@ XMLNode_setAttributes(XMLNode_t *node, const XMLAttributes_t* attributes)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1178,7 +1194,7 @@ XMLNode_addAttr ( XMLNode_t *node,  const char* name, const char* value )
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1215,7 +1231,7 @@ XMLNode_addAttrWithNS ( XMLNode_t *node,  const char* name
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1240,7 +1256,7 @@ XMLNode_addAttrWithTriple (XMLNode_t *node, const XMLTriple_t *triple, const cha
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1267,7 +1283,7 @@ XMLNode_removeAttr (XMLNode_t *node, int n)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1294,7 +1310,7 @@ XMLNode_removeAttrByName (XMLNode_t *node, const char* name)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1320,7 +1336,7 @@ XMLNode_removeAttrByNS (XMLNode_t *node, const char* name, const char* uri)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1344,7 +1360,7 @@ XMLNode_removeAttrByTriple (XMLNode_t *node, const XMLTriple_t *triple)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1744,7 +1760,7 @@ XMLNode_getNamespaces (const XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1773,7 +1789,7 @@ XMLNode_setNamespaces(XMLNode_t *node, const XMLNamespaces_t* namespaces)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1798,7 +1814,7 @@ XMLNode_addNamespace (XMLNode_t *node, const char* uri, const char* prefix)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1823,7 +1839,7 @@ XMLNode_removeNamespace (XMLNode_t *node, int index)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -1848,7 +1864,7 @@ XMLNode_removeNamespaceByPrefix (XMLNode_t *node, const char* prefix)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_XML_OPERATION
@@ -2252,7 +2268,7 @@ XMLNode_isText (const XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2274,7 +2290,7 @@ XMLNode_setEnd (XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
@@ -2296,7 +2312,7 @@ XMLNode_setEOF (XMLNode_t *node)
  *
  * @return integer value indicating success/failure of the
  * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
  * returned by this function are:
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_OPERATION_FAILED
