@@ -25,7 +25,7 @@
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ---------------------------------------------------------------------- -->*/
 
-#if WIN32 && !defined(CYGWIN) 
+#if defined(WIN32) && !defined(CYGWIN) 
 
 #include <iostream>
 
@@ -44,7 +44,8 @@
 
 #include <sbml/common/extern.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -864,12 +865,13 @@ create_suite_XMLAttributes_C (void)
   tcase_add_test( tcase, test_XMLAttributes_readInto_int_C );
   tcase_add_test( tcase, test_XMLAttributes_readInto_uint_C );
   tcase_add_test( tcase, test_XMLAttributes_remove1);
+  tcase_add_test( tcase, test_XMLAttributes_clear1);
   tcase_add_test( tcase, test_XMLAttributes_accessWithNULL     );
   suite_add_tcase(suite, tcase);
 
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
