@@ -30,7 +30,9 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
+
 CK_CPPSTART
 #endif
 
@@ -106,7 +108,7 @@ create_suite_XMLError_C (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
