@@ -33,7 +33,9 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
+
 CK_CPPSTART
 #endif
 
@@ -449,7 +451,7 @@ create_suite_XMLNode_newSetters (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
