@@ -33,7 +33,8 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -278,6 +279,6 @@ create_suite_XMLOutputStream (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
