@@ -31,7 +31,8 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -700,6 +701,6 @@ create_suite_XMLToken (void)
   return suite;
 }
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
