@@ -30,7 +30,8 @@
 
 #include <check.h>
 
-#if __cplusplus
+#if defined(__cplusplus)
+LIBSBML_CPP_NAMESPACE_USE
 CK_CPPSTART
 #endif
 
@@ -115,7 +116,7 @@ create_suite_XMLTriple (void)
 }
 
 
-#if __cplusplus
+#if defined(__cplusplus)
 CK_CPPEND
 #endif
 
